/*
 * Automatically generated file; DO NOT EDIT.
 * Linux/arm64 6.7.5-2 Kernel Configuration
 */
#define CONFIG_IP6_NF_MATCH_AH_MODULE 1
#define CONFIG_NLS_CODEPAGE_861_MODULE 1
#define CONFIG_NF_CONNTRACK_H323_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP_FILTER 1
#define CONFIG_IP6_NF_SECURITY_MODULE 1
#define CONFIG_SND_PROC_FS 1
#define CONFIG_SCSI_DMA 1
#define CONFIG_NETFILTER_FAMILY_BRIDGE 1
#define CONFIG_CC_HAS_SANCOV_TRACE_PC 1
#define CONFIG_DEFAULT_INIT ""
#define CONFIG_ARM64_PAGE_SHIFT 12
#define CONFIG_MV_XOR_V2 1
#define CONFIG_IP_SET_HASH_IPMARK_MODULE 1
#define CONFIG_ARCH_HAS_DEBUG_VM_PGTABLE 1
#define CONFIG_NFT_NAT_MODULE 1
#define CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK 1
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_INET_TABLE_PERTURB_ORDER 16
#define CONFIG_ARCH_SUPPORTS_INT128 1
#define CONFIG_IP_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_MEMORY_ISOLATION 1
#define CONFIG_SLUB_CPU_PARTIAL 1
#define CONFIG_RFS_ACCEL 1
#define CONFIG_SUN50I_A100_CCU 1
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#define CONFIG_ARCH_WANTS_THP_SWAP 1
#define CONFIG_CRC32 1
#define CONFIG_I2C_BOARDINFO 1
#define CONFIG_CROS_EC_PROTO 1
#define CONFIG_NFT_FIB_INET_MODULE 1
#define CONFIG_IP_VS_MH_MODULE 1
#define CONFIG_PNFS_FLEXFILE_LAYOUT 1
#define CONFIG_USB_CONFIGFS_NCM 1
#define CONFIG_NETFILTER_XT_MATCH_CPU_MODULE 1
#define CONFIG_KEY_DH_OPERATIONS 1
#define CONFIG_SECCOMP 1
#define CONFIG_CPU_FREQ_GOV_CONSERVATIVE 1
#define CONFIG_HIGH_RES_TIMERS 1
#define CONFIG_DT_IDLE_GENPD 1
#define CONFIG_ARCH_HAS_SET_MEMORY 1
#define CONFIG_BLK_DEV_DM 1
#define CONFIG_RT2800USB_RT3573 1
#define CONFIG_VLAN_8021Q_MODULE 1
#define CONFIG_IP_MULTIPLE_TABLES 1
#define CONFIG_GCC11_NO_ARRAY_BOUNDS 1
#define CONFIG_UEVENT_HELPER 1
#define CONFIG_XEN_DOM0 1
#define CONFIG_BT_RFCOMM_MODULE 1
#define CONFIG_FIX_EARLYCON_MEM 1
#define CONFIG_LEDS_TRIGGER_HEARTBEAT 1
#define CONFIG_STK8BA50_MODULE 1
#define CONFIG_INOTIFY_USER 1
#define CONFIG_NF_CONNTRACK_NETBIOS_NS_MODULE 1
#define CONFIG_HDMI 1
#define CONFIG_BRIDGE_EBT_T_FILTER_MODULE 1
#define CONFIG_NETWORK_FILESYSTEMS 1
#define CONFIG_NF_FLOW_TABLE_MODULE 1
#define CONFIG_CRYPTO_MD4_MODULE 1
#define CONFIG_SATA_AHCI_PLATFORM_MODULE 1
#define CONFIG_THERMAL_GOV_BANG_BANG 1
#define CONFIG_CPU_FREQ_GOV_ONDEMAND 1
#define CONFIG_ARM64_VA_BITS 48
#define CONFIG_FB_CORE 1
#define CONFIG_GLOB 1
#define CONFIG_ARCH_WANT_LD_ORPHAN_WARN 1
#define CONFIG_CGROUP_DEVICE 1
#define CONFIG_ARM64_CNP 1
#define CONFIG_DMA_BOUNCE_UNALIGNED_KMALLOC 1
#define CONFIG_DRM_PANEL_SITRONIX_ST7703_MODULE 1
#define CONFIG_PPP_SYNC_TTY_MODULE 1
#define CONFIG_ARCH_SUSPEND_POSSIBLE 1
#define CONFIG_MMU_LAZY_TLB_REFCOUNT 1
#define CONFIG_COMPAT_NETLINK_MESSAGES 1
#define CONFIG_RC_CORE_MODULE 1
#define CONFIG_USB_G_SERIAL_MODULE 1
#define CONFIG_CGROUP_WRITEBACK 1
#define CONFIG_PSTORE_DEFAULT_KMSG_BYTES 10240
#define CONFIG_MAC80211_STA_HASH_MAX_SIZE 0
#define CONFIG_NLS_MAC_TURKISH_MODULE 1
#define CONFIG_IP_VS_NQ_MODULE 1
#define CONFIG_HAVE_ARCH_MMAP_RND_BITS 1
#define CONFIG_HIBERNATION 1
#define CONFIG_BLK_DEV_NBD_MODULE 1
#define CONFIG_CPU_FREQ_GOV_ATTR_SET 1
#define CONFIG_ARM64_ERRATUM_1024718 1
#define CONFIG_EXT4_FS_POSIX_ACL 1
#define CONFIG_PHYLINK 1
#define CONFIG_ZSTD_COMPRESS_MODULE 1
#define CONFIG_BINFMT_MISC_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HELPER_MODULE 1
#define CONFIG_SSB_POSSIBLE 1
#define CONFIG_NFS_V4_2 1
#define CONFIG_BRIDGE_EBT_T_NAT_MODULE 1
#define CONFIG_NF_NAT_SIP_MODULE 1
#define CONFIG_USB_F_EEM_MODULE 1
#define CONFIG_MMU_NOTIFIER 1
#define CONFIG_ASYMMETRIC_KEY_TYPE 1
#define CONFIG_VHOST_VSOCK_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATISTIC_MODULE 1
#define CONFIG_NLS_CODEPAGE_855_MODULE 1
#define CONFIG_SPI_DYNAMIC 1
#define CONFIG_ARCH_CORRECT_STACKTRACE_ON_KRETPROBE 1
#define CONFIG_UHID 1
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_USB_CHIPIDEA_GENERIC 1
#define CONFIG_BRIDGE_NF_EBTABLES_MODULE 1
#define CONFIG_CRYPTO_SHA1_ARM64_CE 1
#define CONFIG_FW_LOADER_COMPRESS 1
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_SWPHY 1
#define CONFIG_IOMMU_IO_PGTABLE_LPAE 1
#define CONFIG_THP_SWAP 1
#define CONFIG_FSNOTIFY 1
#define CONFIG_BLK_DEV_LOOP_MIN_COUNT 8
#define CONFIG_STP_MODULE 1
#define CONFIG_INET6_TUNNEL_MODULE 1
#define CONFIG_NF_CONNTRACK_SIP_MODULE 1
#define CONFIG_CRYPTO_MANAGER_DISABLE_TESTS 1
#define CONFIG_HIDRAW 1
#define CONFIG_RT2X00_LIB_LEDS 1
#define CONFIG_NET_PTP_CLASSIFY 1
#define CONFIG_IP_VS_SED_MODULE 1
#define CONFIG_GENERIC_SMP_IDLE_THREAD 1
#define CONFIG_NET_VENDOR_QUALCOMM 1
#define CONFIG_PINCTRL_SINGLE 1
#define CONFIG_SQUASHFS_FILE_CACHE 1
#define CONFIG_ARCH_SUPPORTS_NUMA_BALANCING 1
#define CONFIG_MACVTAP_MODULE 1
#define CONFIG_RTC_DRV_SUN6I 1
#define CONFIG_ARCH_SUPPORTS_CRASH_DUMP 1
#define CONFIG_NET_VENDOR_EZCHIP 1
#define CONFIG_BRIDGE_EBT_REDIRECT_MODULE 1
#define CONFIG_DEFAULT_SECURITY_DAC 1
#define CONFIG_LDISC_AUTOLOAD 1
#define CONFIG_FIB_RULES 1
#define CONFIG_CRYPTO_CRCT10DIF 1
#define CONFIG_CRYPTO_GHASH_ARM64_CE 1
#define CONFIG_USB_CONFIGFS_OBEX 1
#define CONFIG_IP_VS_NFCT 1
#define CONFIG_USB_AUTOSUSPEND_DELAY 2
#define CONFIG_VLAN_8021Q_GVRP 1
#define CONFIG_IP_SET_HASH_NETIFACE_MODULE 1
#define CONFIG_IP6_NF_MANGLE_MODULE 1
#define CONFIG_HAVE_KVM_DIRTY_RING_ACQ_REL 1
#define CONFIG_HAVE_IRQ_TIME_ACCOUNTING 1
#define CONFIG_NETFILTER_XT_MATCH_REALM_MODULE 1
#define CONFIG_SQUASHFS_XATTR 1
#define CONFIG_IP_VS_RR_MODULE 1
#define CONFIG_IPV6 1
#define CONFIG_HAVE_STACKPROTECTOR 1
#define CONFIG_INDIRECT_PIO 1
#define CONFIG_NET_9P 1
#define CONFIG_NET_HANDSHAKE 1
#define CONFIG_CRYPTO_AEAD 1
#define CONFIG_COMPAT 1
#define CONFIG_MAGIC_SYSRQ_SERIAL 1
#define CONFIG_BQL 1
#define CONFIG_GPIO_PCA953X_IRQ 1
#define CONFIG_DEFAULT_TCP_CONG "cubic"
#define CONFIG_UEVENT_HELPER_PATH "/sbin/hotplug"
#define CONFIG_DEVTMPFS 1
#define CONFIG_OF_IOMMU 1
#define CONFIG_PNFS_FILE_LAYOUT 1
#define CONFIG_FRAMEBUFFER_CONSOLE_LEGACY_ACCELERATION 1
#define CONFIG_VIDEO_SUN8I_DEINTERLACE 1
#define CONFIG_SUNRPC_BACKCHANNEL 1
#define CONFIG_NLS_ISO8859_7_MODULE 1
#define CONFIG_ANDROID_BINDER_IPC 1
#define CONFIG_MOUSE_PS2_SMBUS 1
#define CONFIG_IP6_NF_TARGET_REJECT_MODULE 1
#define CONFIG_CPUFREQ_DT 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MAX 16
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_SND_SUN4I_CODEC_MODULE 1
#define CONFIG_NFT_OSF_MODULE 1
#define CONFIG_NF_NAT_REDIRECT 1
#define CONFIG_HOTPLUG_CPU 1
#define CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM 1
#define CONFIG_NLS_MAC_CYRILLIC_MODULE 1
#define CONFIG_SCSI_HISI_SAS_MODULE 1
#define CONFIG_WLAN 1
#define CONFIG_NAMESPACES 1
#define CONFIG_USB_U_AUDIO_MODULE 1
#define CONFIG_HAVE_CMPXCHG_DOUBLE 1
#define CONFIG_CROS_EC_SYSFS 1
#define CONFIG_HAVE_ARCH_HUGE_VMAP 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY 1
#define CONFIG_DRM_GEM_DMA_HELPER 1
#define CONFIG_USB_CONFIGFS_MODULE 1
#define CONFIG_AXP20X_ADC 1
#define CONFIG_BLK_DEV_BSG 1
#define CONFIG_MEDIA_USB_SUPPORT 1
#define CONFIG_NETFILTER_XT_TARGET_RATEEST_MODULE 1
#define CONFIG_CRYPTO_ARCH_HAVE_LIB_CHACHA_MODULE 1
#define CONFIG_BRIDGE_EBT_ARPREPLY_MODULE 1
#define CONFIG_INTEGRITY 1
#define CONFIG_LEGACY_PTYS 1
#define CONFIG_XFRM_IPCOMP_MODULE 1
#define CONFIG_CRYPTO_DRBG_MENU 1
#define CONFIG_CRYPTO_RNG2 1
#define CONFIG_NETFILTER_NETLINK_QUEUE_MODULE 1
#define CONFIG_MFD_CROS_EC_DEV 1
#define CONFIG_THERMAL_WRITABLE_TRIPS 1
#define CONFIG_USB_U_SERIAL_MODULE 1
#define CONFIG_TUN 1
#define CONFIG_WLAN_VENDOR_MICROCHIP 1
#define CONFIG_MMC_DW_HI3798CV200 1
#define CONFIG_NET_VENDOR_DAVICOM 1
#define CONFIG_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_IP_VS_FO_MODULE 1
#define CONFIG_USB_G_MULTI_CDC 1
#define CONFIG_IIO_KFIFO_BUF_MODULE 1
#define CONFIG_ARCH_ENABLE_THP_MIGRATION 1
#define CONFIG_ZRAM_DEF_COMP_LZORLE 1
#define CONFIG_LEDS_TRIGGER_DISK 1
#define CONFIG_CFG80211_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_256KB 1
#define CONFIG_PINCTRL_SUN50I_H616 1
#define CONFIG_GENERIC_PINCTRL_GROUPS 1
#define CONFIG_IP_SET_HASH_NETNET_MODULE 1
#define CONFIG_NLS_CODEPAGE_1250_MODULE 1
#define CONFIG_OF_RESERVED_MEM 1
#define CONFIG_DM_CRYPT 1
#define CONFIG_SERIAL_8250 1
#define CONFIG_CRYPTO_AES_ARM64 1
#define CONFIG_CAVIUM_ERRATUM_30115 1
#define CONFIG_LZO_DECOMPRESS 1
#define CONFIG_USB_EHCI_ROOT_HUB_TT 1
#define CONFIG_IP_VS_PROTO_AH 1
#define CONFIG_IOMMU_SUPPORT 1
#define CONFIG_HID_BELKIN 1
#define CONFIG_VFIO_IOMMU_TYPE1 1
#define CONFIG_STMMAC_PLATFORM_MODULE 1
#define CONFIG_SUN4I_TIMER 1
#define CONFIG_NLS_CODEPAGE_862_MODULE 1
#define CONFIG_WLAN_VENDOR_CISCO 1
#define CONFIG_ARM64_USE_LSE_ATOMICS 1
#define CONFIG_NFSD_MODULE 1
#define CONFIG_COMPAT_BINFMT_ELF 1
#define CONFIG_GCC_SUPPORTS_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_ARCH_SELECTS_KEXEC_FILE 1
#define CONFIG_USB_SERIAL_OPTION_MODULE 1
#define CONFIG_RD_LZMA 1
#define CONFIG_USB 1
#define CONFIG_CHARGER_AXP20X 1
#define CONFIG_GPIO_PL061 1
#define CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK 1
#define CONFIG_PM_WAKELOCKS_GC 1
#define CONFIG_MODULES_USE_ELF_RELA 1
#define CONFIG_CRYPTO_HMAC 1
#define CONFIG_WLAN_VENDOR_REALTEK 1
#define CONFIG_ETHERNET 1
#define CONFIG_FRAMEBUFFER_CONSOLE_ROTATION 1
#define CONFIG_INPUT_BMA150_MODULE 1
#define CONFIG_HID_LOGITECH_HIDPP 1
#define CONFIG_CRYPTO_SHA3 1
#define CONFIG_CRC_ITU_T 1
#define CONFIG_HAVE_DMA_CONTIGUOUS 1
#define CONFIG_DQL 1
#define CONFIG_PINCTRL_SUN50I_A100 1
#define CONFIG_FRAMEBUFFER_CONSOLE 1
#define CONFIG_SOCK_CGROUP_DATA 1
#define CONFIG_COREDUMP 1
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#define CONFIG_HID_CHERRY 1
#define CONFIG_USE_PERCPU_NUMA_NODE_ID 1
#define CONFIG_NFT_FIB_MODULE 1
#define CONFIG_BCMA_POSSIBLE 1
#define CONFIG_USB_CONFIGFS_RNDIS 1
#define CONFIG_NF_LOG_IPV4_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO 1
#define CONFIG_ZRAM_MODULE 1
#define CONFIG_SATA_HOST 1
#define CONFIG_NF_TABLES_ARP 1
#define CONFIG_SND_SOC_MODULE 1
#define CONFIG_SCSI_COMMON 1
#define CONFIG_SURFACE_PLATFORMS 1
#define CONFIG_PRINTK 1
#define CONFIG_BMC150_ACCEL_MODULE 1
#define CONFIG_FB_SYS_FILLRECT 1
#define CONFIG_TIMERFD 1
#define CONFIG_CRYPTO_LIB_CHACHA_GENERIC 1
#define CONFIG_SENSORS_LIS3_SPI_MODULE 1
#define CONFIG_DNS_RESOLVER 1
#define CONFIG_GPIO_MAX77620 1
#define CONFIG_MTD_CFI_I2 1
#define CONFIG_CRYPTO_AUTHENC 1
#define CONFIG_AT803X_PHY_MODULE 1
#define CONFIG_VIDEO_V4L2_SUBDEV_API 1
#define CONFIG_NLS_MAC_CENTEURO_MODULE 1
#define CONFIG_BRCMFMAC_SDIO 1
#define CONFIG_ARCH_HAS_SYSCALL_WRAPPER 1
#define CONFIG_DWMAC_GENERIC_MODULE 1
#define CONFIG_NUMA_BALANCING 1
#define CONFIG_COMPAT_32BIT_TIME 1
#define CONFIG_SHMEM 1
#define CONFIG_MTD 1
#define CONFIG_MIGRATION 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL 1
#define CONFIG_BUILD_SALT ""
#define CONFIG_MMC_BLOCK_MINORS 32
#define CONFIG_F2FS_FS_LZ4 1
#define CONFIG_HAVE_ARCH_PREL32_RELOCATIONS 1
#define CONFIG_DECOMPRESS_LZMA 1
#define CONFIG_HAVE_KVM_EVENTFD 1
#define CONFIG_DEVTMPFS_MOUNT 1
#define CONFIG_EXCLUSIVE_SYSTEM_RAM 1
#define CONFIG_NLS_CODEPAGE_850_MODULE 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC 1
#define CONFIG_DNOTIFY 1
#define CONFIG_AS_HAS_ARMV8_3 1
#define CONFIG_SCSI_UFSHCD_MODULE 1
#define CONFIG_THERMAL_STATISTICS 1
#define CONFIG_ARCH_HAS_GENERIC_CRASHKERNEL_RESERVATION 1
#define CONFIG_GENERIC_NET_UTILS 1
#define CONFIG_ATA_MODULE 1
#define CONFIG_CRYPTO_DES_MODULE 1
#define CONFIG_USB_ROLE_SWITCH 1
#define CONFIG_GPIOLIB_FASTPATH_LIMIT 512
#define CONFIG_MMC_ARMMMCI 1
#define CONFIG_NLS_CODEPAGE_437 1
#define CONFIG_DRM_DISPLAY_CONNECTOR_MODULE 1
#define CONFIG_BT_HS 1
#define CONFIG_ARCH_PROC_KCORE_TEXT 1
#define CONFIG_NETFILTER_NETLINK_GLUE_CT 1
#define CONFIG_EXPORTFS 1
#define CONFIG_IP6_NF_MATCH_MH_MODULE 1
#define CONFIG_NET_INGRESS 1
#define CONFIG_BLK_DEV_INTEGRITY_T10 1
#define CONFIG_HAVE_FUNCTION_ERROR_INJECTION 1
#define CONFIG_ARM64_ERRATUM_1286807 1
#define CONFIG_ARM_GIC 1
#define CONFIG_OLD_SIGSUSPEND3 1
#define CONFIG_SERIO 1
#define CONFIG_TYPEC_UCSI_MODULE 1
#define CONFIG_INPUT_MOUSE 1
#define CONFIG_FB_SYS_IMAGEBLIT 1
#define CONFIG_SUNRPC_GSS 1
#define CONFIG_KCMP 1
#define CONFIG_SENSORS_LM90_MODULE 1
#define CONFIG_RTC_INTF_SYSFS 1
#define CONFIG_GCC_PLUGINS 1
#define CONFIG_CPU_FREQ_GOV_COMMON 1
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_MMC_SUNXI 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTREMOVE 1
#define CONFIG_PCPU_DEV_REFCNT 1
#define CONFIG_LEDS_TRIGGER_TIMER 1
#define CONFIG_RT2800_LIB_MODULE 1
#define CONFIG_BT_INTEL_MODULE 1
#define CONFIG_NF_CONNTRACK_SANE_MODULE 1
#define CONFIG_FB_SYSMEM_HELPERS 1
#define CONFIG_SERIAL_DEV_BUS 1
#define CONFIG_USB_OTG 1
#define CONFIG_PREEMPT_NOTIFIERS 1
#define CONFIG_NF_CT_PROTO_DCCP 1
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_USB_FUNCTIONFS_MODULE 1
#define CONFIG_NET_VENDOR_SYNOPSYS 1
#define CONFIG_NFT_FLOW_OFFLOAD_MODULE 1
#define CONFIG_CRC_T10DIF 1
#define CONFIG_NF_CONNTRACK_BRIDGE_MODULE 1
#define CONFIG_THERMAL_GOV_FAIR_SHARE 1
#define CONFIG_THERMAL_OF 1
#define CONFIG_HWMON 1
#define CONFIG_LOGO_LINUX_CLUT224 1
#define CONFIG_BT_HCIUART_3WIRE 1
#define CONFIG_USB_PHY 1
#define CONFIG_NLS_ISO8859_2_MODULE 1
#define CONFIG_IP_PNP 1
#define CONFIG_USB_VIDEO_CLASS_MODULE 1
#define CONFIG_RTC_INTF_PROC 1
#define CONFIG_PM_CLK 1
#define CONFIG_USB_CONFIGFS_F_HID 1
#define CONFIG_CMA_SIZE_SEL_MBYTES 1
#define CONFIG_CC_IMPLICIT_FALLTHROUGH "-Wimplicit-fallthrough=5"
#define CONFIG_CPU_IDLE_GOV_MENU 1
#define CONFIG_ARCH_HAS_UBSAN_SANITIZE_ALL 1
#define CONFIG_STACKTRACE_SUPPORT 1
#define CONFIG_MEDIA_CONTROLLER_REQUEST_API 1
#define CONFIG_RESET_CONTROLLER 1
#define CONFIG_USB_CHIPIDEA_MSM 1
#define CONFIG_IP_SET_HASH_IPMAC_MODULE 1
#define CONFIG_USB_ISP1760 1
#define CONFIG_LOCKD 1
#define CONFIG_MFD_AXP20X_RSB 1
#define CONFIG_USB_F_FS_MODULE 1
#define CONFIG_USB_CHIPIDEA_UDC 1
#define CONFIG_NF_CT_NETLINK_TIMEOUT_MODULE 1
#define CONFIG_CRYPTO_LIB_ARC4_MODULE 1
#define CONFIG_CRYPTO_LIB_AES 1
#define CONFIG_RT2800USB_RT35XX 1
#define CONFIG_WLAN_VENDOR_RALINK 1
#define CONFIG_CRYPTO_KPP2 1
#define CONFIG_NET_VENDOR_MICROCHIP 1
#define CONFIG_NEED_SG_DMA_FLAGS 1
#define CONFIG_FUNCTION_ALIGNMENT 4
#define CONFIG_NFT_REJECT_IPV6_MODULE 1
#define CONFIG_BT_RFCOMM_TTY 1
#define CONFIG_ARM64_ERRATUM_2658417 1
#define CONFIG_NET_UDP_TUNNEL_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5 1
#define CONFIG_CRYPTO_ECC_MODULE 1
#define CONFIG_NO_HZ_IDLE 1
#define CONFIG_MFD_VEXPRESS_SYSREG 1
#define CONFIG_USB_ISP1761_UDC 1
#define CONFIG_NLS_MAC_ROMANIAN_MODULE 1
#define CONFIG_CFG80211_REQUIRE_SIGNED_REGDB 1
#define CONFIG_ARCH_BINFMT_ELF_EXTRA_PHDRS 1
#define CONFIG_MOUSE_PS2_BYD 1
#define CONFIG_F2FS_STAT_FS 1
#define CONFIG_BSD_PROCESS_ACCT 1
#define CONFIG_NETFILTER_XT_MATCH_STRING_MODULE 1
#define CONFIG_SOCK_RX_QUEUE_MAPPING 1
#define CONFIG_CRYPTO_DRBG_HMAC 1
#define CONFIG_PM_AUTOSLEEP 1
#define CONFIG_I2C_RK3X 1
#define CONFIG_DRM_BRIDGE 1
#define CONFIG_FB_DEVICE 1
#define CONFIG_USB_F_SERIAL_MODULE 1
#define CONFIG_USB_G_MULTI_RNDIS 1
#define CONFIG_LOGO 1
#define CONFIG_SND_SOC_MAX98357A_MODULE 1
#define CONFIG_STK8312_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_BPF_MODULE 1
#define CONFIG_ARCH_SUPPORTS_PER_VMA_LOCK 1
#define CONFIG_USB_STORAGE 1
#define CONFIG_NET_VENDOR_BROADCOM 1
#define CONFIG_GENERIC_CPU_AUTOPROBE 1
#define CONFIG_STANDALONE 1
#define CONFIG_SCHED_MC 1
#define CONFIG_CPU_FREQ_GOV_PERFORMANCE 1
#define CONFIG_RATIONAL 1
#define CONFIG_I2C_MUX 1
#define CONFIG_WLAN_VENDOR_INTEL 1
#define CONFIG_HAVE_SETUP_PER_CPU_AREA 1
#define CONFIG_ARM64_LSE_ATOMICS 1
#define CONFIG_SYSTEM_TRUSTED_KEYRING 1
#define CONFIG_WATCHDOG_CORE 1
#define CONFIG_BCM_SBA_RAID_MODULE 1
#define CONFIG_GENERIC_EARLY_IOREMAP 1
#define CONFIG_SND_USB_AUDIO_MODULE 1
#define CONFIG_NET_VENDOR_WANGXUN 1
#define CONFIG_AMPERE_ERRATUM_AC03_CPU_38 1
#define CONFIG_VMAP_STACK 1
#define CONFIG_BLOCK 1
#define CONFIG_IP_VS_LC_MODULE 1
#define CONFIG_ARCH_STACKWALK 1
#define CONFIG_HID_APPLE 1
#define CONFIG_INIT_ENV_ARG_LIMIT 32
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1
#define CONFIG_F2FS_FS_LZORLE 1
#define CONFIG_VIDEO_OV5640_MODULE 1
#define CONFIG_ROOT_NFS 1
#define CONFIG_PWM_SUN4I 1
#define CONFIG_EXFAT_FS_MODULE 1
#define CONFIG_DRM_LIMA 1
#define CONFIG_AF_UNIX_OOB 1
#define CONFIG_USER_NS 1
#define CONFIG_ARCH_WANT_BATCHED_UNMAP_TLB_FLUSH 1
#define CONFIG_CRYPTO_USER 1
#define CONFIG_NF_CONNTRACK_PPTP_MODULE 1
#define CONFIG_TMPFS_POSIX_ACL 1
#define CONFIG_STRICT_KERNEL_RWX 1
#define CONFIG_BUG 1
#define CONFIG_MAC80211_HAS_RC 1
#define CONFIG_ARCH_HAS_DEBUG_WX 1
#define CONFIG_OF_OVERLAY 1
#define CONFIG_ARM64_VA_BITS_48 1
#define CONFIG_XEN 1
#define CONFIG_IRQ_TIME_ACCOUNTING 1
#define CONFIG_ARCH_HAS_MEMBARRIER_SYNC_CORE 1
#define CONFIG_PM 1
#define CONFIG_PPS 1
#define CONFIG_NETFILTER_XTABLES_COMPAT 1
#define CONFIG_LEDS_TRIGGER_PATTERN 1
#define CONFIG_MEMCG 1
#define CONFIG_SPI 1
#define CONFIG_RTC_SYSTOHC_DEVICE "rtc0"
#define CONFIG_V4L_MEM2MEM_DRIVERS 1
#define CONFIG_HAVE_KVM_CPU_RELAX_INTERCEPT 1
#define CONFIG_NFT_HASH_MODULE 1
#define CONFIG_NF_CONNTRACK_IRC_MODULE 1
#define CONFIG_OF_IRQ 1
#define CONFIG_LIBFDT 1
#define CONFIG_NET_FAILOVER 1
#define CONFIG_WLAN_VENDOR_PURELIFI 1
#define CONFIG_PPP_DEFLATE_MODULE 1
#define CONFIG_NTFS_RW 1
#define CONFIG_TEXTSEARCH_KMP_MODULE 1
#define CONFIG_IO_URING 1
#define CONFIG_SERIO_AMBAKMI 1
#define CONFIG_CRYPTO_CRC64_ROCKSOFT 1
#define CONFIG_VT 1
#define CONFIG_USB_NET_NET1080_MODULE 1
#define CONFIG_HID_REDRAGON 1
#define CONFIG_STK3310_MODULE 1
#define CONFIG_SECRETMEM 1
#define CONFIG_DTC 1
#define CONFIG_NETFILTER_XT_TARGET_CLASSIFY_MODULE 1
#define CONFIG_MACB 1
#define CONFIG_REGMAP_SPI 1
#define CONFIG_BT_BREDR 1
#define CONFIG_WATCHDOG_HANDLE_BOOT_ENABLED 1
#define CONFIG_SPLIT_PTLOCK_CPUS 4
#define CONFIG_SBITMAP 1
#define CONFIG_POWER_SUPPLY 1
#define CONFIG_SCSI_UFSHCD_PLATFORM_MODULE 1
#define CONFIG_CIFS_XATTR 1
#define CONFIG_SND_DMAENGINE_PCM_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFQUEUE_MODULE 1
#define CONFIG_WEXT_CORE 1
#define CONFIG_I2C_DESIGNWARE_CORE 1
#define CONFIG_GENERIC_IRQ_CHIP 1
#define CONFIG_AS_HAS_ARMV8_4 1
#define CONFIG_ROCKCHIP_ERRATUM_3588001 1
#define CONFIG_CRYPTO_SKCIPHER2 1
#define CONFIG_NLS 1
#define CONFIG_NF_CONNTRACK_TIMEOUT 1
#define CONFIG_ARCH_WANTS_NO_INSTR 1
#define CONFIG_MDIO_BUS_MUX_MMIOREG 1
#define CONFIG_SUN50I_H6_CCU 1
#define CONFIG_V4L2_FLASH_LED_CLASS 1
#define CONFIG_IP_SET_HASH_IPPORTNET_MODULE 1
#define CONFIG_SCHED_AUTOGROUP 1
#define CONFIG_SPI_SPIDEV_MODULE 1
#define CONFIG_AS_IS_GNU 1
#define CONFIG_MEDIA_CAMERA_SUPPORT 1
#define CONFIG_ARM64_PAN 1
#define CONFIG_CROS_EC_SENSORHUB 1
#define CONFIG_I2C_GPIO_MODULE 1
#define CONFIG_USB_CONFIGFS_ACM 1
#define CONFIG_CGROUP_BPF 1
#define CONFIG_PPPOE_MODULE 1
#define CONFIG_ZONE_DMA 1
#define CONFIG_SUN50I_H6_R_CCU 1
#define CONFIG_CPU_THERMAL 1
#define CONFIG_NETFILTER_XT_MATCH_OWNER_MODULE 1
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#define CONFIG_SYN_COOKIES 1
#define CONFIG_IRQ_WORK 1
#define CONFIG_IP_ADVANCED_ROUTER 1
#define CONFIG_ARCH_SUPPORTS_SHADOW_CALL_STACK 1
#define CONFIG_FB_SYS_COPYAREA 1
#define CONFIG_HAVE_ARCH_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_OPTEE 1
#define CONFIG_SPARSEMEM_EXTREME 1
#define CONFIG_CC_HAS_BRANCH_PROT_PAC_RET_BTI 1
#define CONFIG_USB_COMMON 1
#define CONFIG_TASK_XACCT 1
#define CONFIG_DRM_DISPLAY_HDMI_HELPER 1
#define CONFIG_HIX5HD2_GMAC 1
#define CONFIG_IP_SET_BITMAP_PORT_MODULE 1
#define CONFIG_IP6_NF_IPTABLES_MODULE 1
#define CONFIG_LZ4_COMPRESS_MODULE 1
#define CONFIG_KVM_VFIO 1
#define CONFIG_USB_HSIC_USB3503 1
#define CONFIG_FIXED_PHY 1
#define CONFIG_MFD_SUN6I_PRCM 1
#define CONFIG_NLS_MAC_GAELIC_MODULE 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_LOG_CPU_MAX_BUF_SHIFT 12
#define CONFIG_CRYPTO_JITTERENTROPY_MEMORY_BLOCKSIZE 32
#define CONFIG_NF_DUP_IPV4_MODULE 1
#define CONFIG_BLK_DEV_DM_BUILTIN 1
#define CONFIG_DRM_SUN8I_TCON_TOP 1
#define CONFIG_INET_IPCOMP_MODULE 1
#define CONFIG_ARM64_LD_HAS_FIX_ERRATUM_843419 1
#define CONFIG_TASKS_RCU 1
#define CONFIG_GENERIC_PINCONF 1
#define CONFIG_HNS_MDIO 1
#define CONFIG_ARM_ARCH_TIMER 1
#define CONFIG_ARCH_HAS_NMI_SAFE_THIS_CPU_OPS 1
#define CONFIG_HID_CYPRESS 1
#define CONFIG_NFS_V4_2_SSC_HELPER 1
#define CONFIG_SG_POOL 1
#define CONFIG_BRIDGE_EBT_LIMIT_MODULE 1
#define CONFIG_DRM_KMS_HELPER 1
#define CONFIG_DMA_COHERENT_POOL 1
#define CONFIG_ARM_ALLWINNER_SUN50I_CPUFREQ_NVMEM 1
#define CONFIG_NF_SOCKET_IPV6_MODULE 1
#define CONFIG_USB_NET_PLUSB_MODULE 1
#define CONFIG_REGULATOR_PWM 1
#define CONFIG_CRYPTO_LIB_CURVE25519_MODULE 1
#define CONFIG_CPU_FREQ_THERMAL 1
#define CONFIG_NLS_ISO8859_1_MODULE 1
#define CONFIG_MMC_CQHCI 1
#define CONFIG_HID_KENSINGTON 1
#define CONFIG_USB_EHCI_HCD 1
#define CONFIG_TEXTSEARCH_BM_MODULE 1
#define CONFIG_FS_IOMAP 1
#define CONFIG_NF_CONNTRACK_PROCFS 1
#define CONFIG_NLS_MAC_INUIT_MODULE 1
#define CONFIG_PHY_QCOM_USB_HS 1
#define CONFIG_BT_HCIUART_LL 1
#define CONFIG_PPP_MPPE_MODULE 1
#define CONFIG_COMPACT_UNEVICTABLE_DEFAULT 1
#define CONFIG_RD_ZSTD 1
#define CONFIG_RFKILL_MODULE 1
#define CONFIG_NETDEVICES 1
#define CONFIG_NET_KEY_MODULE 1
#define CONFIG_IP6_NF_TARGET_HL_MODULE 1
#define CONFIG_NF_FLOW_TABLE_PROCFS 1
#define CONFIG_NETFILTER_CONNCOUNT_MODULE 1
#define CONFIG_ARCH_HAS_KCOV 1
#define CONFIG_CGROUP_FREEZER 1
#define CONFIG_HAVE_ARCH_STACKLEAK 1
#define CONFIG_EVENTFD 1
#define CONFIG_SUN50I_A100_R_CCU 1
#define CONFIG_PHY_SUN4I_USB 1
#define CONFIG_VLAN_8021Q_MVRP 1
#define CONFIG_FS_POSIX_ACL 1
#define CONFIG_IPV6_SIT_MODULE 1
#define CONFIG_XFRM 1
#define CONFIG_SND_SOC_BT_SCO_MODULE 1
#define CONFIG_USB_F_UAC2_MODULE 1
#define CONFIG_LINEAR_RANGES 1
#define CONFIG_IP_SET_HASH_IP_MODULE 1
#define CONFIG_AS_HAS_LDAPR 1
#define CONFIG_SERIAL_8250_CONSOLE 1
#define CONFIG_IPV6_MULTIPLE_TABLES 1
#define CONFIG_CRYPTO_GENIV 1
#define CONFIG_JUMP_LABEL 1
#define CONFIG_ARCH_HAS_TEARDOWN_DMA_OPS 1
#define CONFIG_CHARGER_CROS_PCHG 1
#define CONFIG_OVERLAY_FS_MODULE 1
#define CONFIG_IP_SET_HASH_NETPORT_MODULE 1
#define CONFIG_CIFS_ALLOW_INSECURE_LEGACY 1
#define CONFIG_IP_VS_DH_MODULE 1
#define CONFIG_VIDEO_MEM2MEM_DEINTERLACE 1
#define CONFIG_PPPOE_HASH_BITS_4 1
#define CONFIG_COMMON_CLK_CS2000_CP 1
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_USERMODE_DRIVER 1
#define CONFIG_HAVE_EBPF_JIT 1
#define CONFIG_NF_CONNTRACK_BROADCAST_MODULE 1
#define CONFIG_NFT_FWD_NETDEV_MODULE 1
#define CONFIG_PROC_PAGE_MONITOR 1
#define CONFIG_USB_CONFIGFS_ECM 1
#define CONFIG_SERIAL_8250_EXTENDED 1
#define CONFIG_NETFILTER_XT_TARGET_MASQUERADE_MODULE 1
#define CONFIG_SND_SUN8I_CODEC_MODULE 1
#define CONFIG_MTD_SPI_NOR_USE_4K_SECTORS 1
#define CONFIG_TYPEC_DP_ALTMODE_MODULE 1
#define CONFIG_BPF 1
#define CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV 1
#define CONFIG_DWMAC_SUN8I_MODULE 1
#define CONFIG_CRYPTO_AES_ARM64_CE_CCM 1
#define CONFIG_USB_SERIAL_CH341_MODULE 1
#define CONFIG_RD_LZO 1
#define CONFIG_IP_SET_HASH_IPPORT_MODULE 1
#define CONFIG_F2FS_FS_ZSTD 1
#define CONFIG_HAVE_FUNCTION_GRAPH_RETVAL 1
#define CONFIG_ARM64_RAS_EXTN 1
#define CONFIG_CRYPTO_SHA512 1
#define CONFIG_TEE 1
#define CONFIG_BACKLIGHT_CLASS_DEVICE 1
#define CONFIG_CC_HAS_ASM_INLINE 1
#define CONFIG_VHOST_MODULE 1
#define CONFIG_MTD_OF_PARTS 1
#define CONFIG_RT2X00_LIB_USB_MODULE 1
#define CONFIG_SND_SUN4I_SPDIF_MODULE 1
#define CONFIG_OF_RESOLVE 1
#define CONFIG_CRYPTO_NULL 1
#define CONFIG_GPIO_CDEV_V1 1
#define CONFIG_NET_VENDOR_SEEQ 1
#define CONFIG_NF_DEFRAG_IPV4_MODULE 1
#define CONFIG_PINCTRL_SUN50I_H6_R 1
#define CONFIG_ARCH_HAS_RELR 1
#define CONFIG_ARCH_FORCE_MAX_ORDER 10
#define CONFIG_NETFILTER_ADVANCED 1
#define CONFIG_CRYPTO_DEFLATE 1
#define CONFIG_GENERIC_STRNLEN_USER 1
#define CONFIG_ARM64_TAGGED_ADDR_ABI 1
#define CONFIG_NFT_DUP_NETDEV_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_TCPMSS_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPCOMP_MODULE 1
#define CONFIG_MITIGATE_SPECTRE_BRANCH_HISTORY 1
#define CONFIG_WLAN_VENDOR_RSI 1
#define CONFIG_SLIP_COMPRESSED 1
#define CONFIG_CRYPTO_JITTERENTROPY 1
#define CONFIG_TYPEC_MODULE 1
#define CONFIG_ARCH_ENABLE_HUGEPAGE_MIGRATION 1
#define CONFIG_NETFILTER_XT_MATCH_L2TP_MODULE 1
#define CONFIG_BT_HCIUART_SERDEV 1
#define CONFIG_GENERIC_ARCH_NUMA 1
#define CONFIG_CRYPTO_GCM 1
#define CONFIG_NETFILTER_NETLINK_LOG_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE 1
#define CONFIG_NLS_ISO8859_14_MODULE 1
#define CONFIG_ARM64_SME 1
#define CONFIG_MAGIC_SYSRQ 1
#define CONFIG_QCOM_FALKOR_ERRATUM_1009 1
#define CONFIG_CROS_EC_CHARDEV 1
#define CONFIG_USB_CONFIGFS_F_FS 1
#define CONFIG_THERMAL_EMULATION 1
#define CONFIG_ARM64_ERRATUM_845719 1
#define CONFIG_CRYPTO_KPP 1
#define CONFIG_PNFS_BLOCK 1
#define CONFIG_PGTABLE_LEVELS 4
#define CONFIG_POWER_RESET_SYSCON 1
#define CONFIG_CPUSETS 1
#define CONFIG_NETFILTER_XT_MATCH_MARK_MODULE 1
#define CONFIG_SMBFS_MODULE 1
#define CONFIG_MAC80211_RC_DEFAULT_MINSTREL 1
#define CONFIG_SPARSE_IRQ 1
#define CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP_MODULE 1
#define CONFIG_ARM64_ERRATUM_1508412 1
#define CONFIG_IP_NF_MANGLE_MODULE 1
#define CONFIG_USB_MASS_STORAGE_MODULE 1
#define CONFIG_DT_IDLE_STATES 1
#define CONFIG_DRM_UDL_MODULE 1
#define CONFIG_SECURITYFS 1
#define CONFIG_RTC_DRV_S5M 1
#define CONFIG_ARM64_ERRATUM_2067961 1
#define CONFIG_RCU_STALL_COMMON 1
#define CONFIG_BRIDGE_EBT_VLAN_MODULE 1
#define CONFIG_MEDIA_SUPPORT 1
#define CONFIG_NFT_FIB_IPV6_MODULE 1
#define CONFIG_DEBUG_BUGVERBOSE 1
#define CONFIG_IP_NF_FILTER_MODULE 1
#define CONFIG_EXT3_FS 1
#define CONFIG_ARM64_PTR_AUTH 1
#define CONFIG_IP5XXX_POWER 1
#define CONFIG_NETFILTER_XT_MATCH_LENGTH_MODULE 1
#define CONFIG_BRIDGE_EBT_PKTTYPE_MODULE 1
#define CONFIG_MODULES_TREE_LOOKUP 1
#define CONFIG_FAT_FS 1
#define CONFIG_TEXTSEARCH_FSM_MODULE 1
#define CONFIG_ARM64_ERRATUM_832075 1
#define CONFIG_IP6_NF_RAW_MODULE 1
#define CONFIG_BUILDTIME_TABLE_SORT 1
#define CONFIG_SERIAL_XILINX_PS_UART_CONSOLE 1
#define CONFIG_NVMEM 1
#define CONFIG_INET_TUNNEL_MODULE 1
#define CONFIG_BMA220_MODULE 1
#define CONFIG_NF_LOG_ARP_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NOTRACK_MODULE 1
#define CONFIG_PINCONF 1
#define CONFIG_BLOCK_HOLDER_DEPRECATED 1
#define CONFIG_GENERIC_CLOCKEVENTS 1
#define CONFIG_OID_REGISTRY 1
#define CONFIG_MFD_CORE 1
#define CONFIG_SERIAL_AMBA_PL011 1
#define CONFIG_RTC_DRV_MAX77686 1
#define CONFIG_RFKILL_LEDS 1
#define CONFIG_BT_HCIBTUSB_BCM 1
#define CONFIG_CONSOLE_TRANSLATIONS 1
#define CONFIG_ARCH_SUPPORTS_ATOMIC_RMW 1
#define CONFIG_GENERIC_LIB_DEVMEM_IS_ALLOWED 1
#define CONFIG_RAID6_PQ_MODULE 1
#define CONFIG_SUN6I_RTC_CCU 1
#define CONFIG_SWIOTLB_XEN 1
#define CONFIG_BRIDGE_EBT_IP6_MODULE 1
#define CONFIG_CRYPTO_AES_ARM64_CE 1
#define CONFIG_NF_NAT_SNMP_BASIC_MODULE 1
#define CONFIG_NFT_FIB_NETDEV_MODULE 1
#define CONFIG_SERIAL_EARLYCON 1
#define CONFIG_NET_VENDOR_NI 1
#define CONFIG_CC_HAS_KASAN_SW_TAGS 1
#define CONFIG_CRYPTO_AKCIPHER 1
#define CONFIG_ETHTOOL_NETLINK 1
#define CONFIG_CPU_FREQ 1
#define CONFIG_USB_OHCI_HCD 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_FILE 1
#define CONFIG_USB_GSPCA_MODULE 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_SERIAL_AMBA_PL011_CONSOLE 1
#define CONFIG_CROS_EC_DEBUGFS 1
#define CONFIG_RFKILL_GPIO_MODULE 1
#define CONFIG_NF_REJECT_IPV4 1
#define CONFIG_GENERIC_IOREMAP 1
#define CONFIG_ARCH_MMAP_RND_BITS_MAX 33
#define CONFIG_USB_LAN78XX_MODULE 1
#define CONFIG_NFT_CONNLIMIT_MODULE 1
#define CONFIG_NVMEM_SUNXI_SID 1
#define CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE 1
#define CONFIG_ARM_SP805_WATCHDOG 1
#define CONFIG_TRACE_IRQFLAGS_SUPPORT 1
#define CONFIG_MFD_SYSCON 1
#define CONFIG_NFT_NUMGEN_MODULE 1
#define CONFIG_CRYPTO_AES_ARM64_NEON_BLK 1
#define CONFIG_CRYPTO_CCM_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET_MODULE 1
#define CONFIG_HNS_DSAF 1
#define CONFIG_ARM_PMUV3 1
#define CONFIG_BT_RTL_MODULE 1
#define CONFIG_ARM64_ERRATUM_824069 1
#define CONFIG_TAP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNMARK_MODULE 1
#define CONFIG_BLK_CGROUP 1
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_CRYPTO_RNG 1
#define CONFIG_ATH10K_MODULE 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MIN 11
#define CONFIG_MVMDIO 1
#define CONFIG_CRYPTO_LIB_UTILS 1
#define CONFIG_SND_SUN50I_CODEC_ANALOG_MODULE 1
#define CONFIG_SND_USB 1
#define CONFIG_VIDEOBUF2_MEMOPS 1
#define CONFIG_RTC_DRV_DS3232_HWMON 1
#define CONFIG_RD_GZIP 1
#define CONFIG_MFD_MAX77620 1
#define CONFIG_HAVE_REGS_AND_STACK_ACCESS_API 1
#define CONFIG_BLK_PM 1
#define CONFIG_CRYPTO_ARCH_HAVE_LIB_POLY1305_MODULE 1
#define CONFIG_MDIO_BUS 1
#define CONFIG_TREE_RCU 1
#define CONFIG_PWM_SYSFS 1
#define CONFIG_VIDEO_SUN8I_ROTATE 1
#define CONFIG_ALLOW_DEV_COREDUMP 1
#define CONFIG_SOC_TI 1
#define CONFIG_SUNXI_CCU 1
#define CONFIG_SWIOTLB 1
#define CONFIG_EXT4_FS_SECURITY 1
#define CONFIG_GRO_CELLS 1
#define CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_ARM64_BTI 1
#define CONFIG_CRYPTO_MD5_MODULE 1
#define CONFIG_TRANSPARENT_HUGEPAGE 1
#define CONFIG_VSOCKETS_LOOPBACK_MODULE 1
#define CONFIG_USB_CHIPIDEA 1
#define CONFIG_ARCH_DEFAULT_KEXEC_IMAGE_VERIFY_SIG 1
#define CONFIG_RT2800USB_RT53XX 1
#define CONFIG_NET_VENDOR_CORTINA 1
#define CONFIG_ELFCORE 1
#define CONFIG_REGULATOR_BD9571MWV 1
#define CONFIG_HIBERNATION_SNAPSHOT_DEV 1
#define CONFIG_HAVE_KVM 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER 1
#define CONFIG_INIT_STACK_NONE 1
#define CONFIG_BINFMT_ELF 1
#define CONFIG_I2C_HID 1
#define CONFIG_IIO_TRIGGER 1
#define CONFIG_ARM_PSCI_CPUIDLE 1
#define CONFIG_HAVE_PERF_REGS 1
#define CONFIG_V4L2_ASYNC 1
#define CONFIG_CIFS_DEBUG 1
#define CONFIG_HAVE_KVM_MSI 1
#define CONFIG_INET6_AH_MODULE 1
#define CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT 1
#define CONFIG_TARGET_CORE_MODULE 1
#define CONFIG_NFS_V4_SECURITY_LABEL 1
#define CONFIG_USB_SERIAL_MODULE 1
#define CONFIG_NFT_DUP_IPV4_MODULE 1
#define CONFIG_REGULATOR_FIXED_VOLTAGE 1
#define CONFIG_CROS_EC_VBC 1
#define CONFIG_NET_VENDOR_RENESAS 1
#define CONFIG_KEYS 1
#define CONFIG_INET_XFRM_TUNNEL_MODULE 1
#define CONFIG_NETFILTER_XT_MARK_MODULE 1
#define CONFIG_NETFILTER_XTABLES 1
#define CONFIG_DRM_PANEL_ORIENTATION_QUIRKS 1
#define CONFIG_IP_VS_LBLC_MODULE 1
#define CONFIG_HAVE_KVM_IRQ_BYPASS 1
#define CONFIG_USB_ISP1760_HCD 1
#define CONFIG_MFD_AXP20X_I2C 1
#define CONFIG_CRYPTO_ECHAINIV 1
#define CONFIG_HAVE_ARCH_AUDITSYSCALL 1
#define CONFIG_LEGACY_TIOCSTI 1
#define CONFIG_PINCTRL_SUN50I_A64_R 1
#define CONFIG_ARM64_PA_BITS_48 1
#define CONFIG_MMC_STM32_SDMMC 1
#define CONFIG_CRYPTO_USER_API_HASH 1
#define CONFIG_PM_SLEEP_SMP 1
#define CONFIG_CRYPTO_HW 1
#define CONFIG_ARM64_ERRATUM_3117295 1
#define CONFIG_IIO_ST_MAGN_SPI_3AXIS_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_HWSPINLOCK 1
#define CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE 0x1
#define CONFIG_MFD_HI6421_PMIC 1
#define CONFIG_IIO_INV_SENSORS_TIMESTAMP_MODULE 1
#define CONFIG_HARDIRQS_SW_RESEND 1
#define CONFIG_SPI_MASTER 1
#define CONFIG_DRM_PANEL_FEIYANG_FY07024DI26A30D 1
#define CONFIG_ARCH_HAS_KEEPINITRD 1
#define CONFIG_VT_HW_CONSOLE_BINDING 1
#define CONFIG_NF_TABLES_NETDEV 1
#define CONFIG_SLIP_MODE_SLIP6 1
#define CONFIG_SRAM 1
#define CONFIG_USB_WDM_MODULE 1
#define CONFIG_THERMAL_HWMON 1
#define CONFIG_UNMAP_KERNEL_AT_EL0 1
#define CONFIG_CRYPTO_SKCIPHER 1
#define CONFIG_USB_CHIPIDEA_TEGRA 1
#define CONFIG_ZSWAP_COMPRESSOR_DEFAULT_LZO 1
#define CONFIG_XZ_DEC_X86 1
#define CONFIG_SERIAL_OF_PLATFORM 1
#define CONFIG_MAC80211_LEDS 1
#define CONFIG_NETFILTER_XT_TARGET_TPROXY_MODULE 1
#define CONFIG_HIBERNATE_CALLBACKS 1
#define CONFIG_SERIAL_8250_DW 1
#define CONFIG_ARM_SCPI_PROTOCOL 1
#define CONFIG_THERMAL_EMERGENCY_POWEROFF_DELAY_MS 0
#define CONFIG_CONSOLE_LOGLEVEL_QUIET 4
#define CONFIG_COMMON_CLK_S2MPS11 1
#define CONFIG_USB_RTL8150_MODULE 1
#define CONFIG_CRC16 1
#define CONFIG_USB_NET_AX8817X_MODULE 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_NLS_ISO8859_6_MODULE 1
#define CONFIG_TMPFS 1
#define CONFIG_DRM_MALI_DISPLAY_MODULE 1
#define CONFIG_NFT_CT_MODULE 1
#define CONFIG_RANDSTRUCT_NONE 1
#define CONFIG_USB_OHCI_HCD_PLATFORM 1
#define CONFIG_NLS_CODEPAGE_936_MODULE 1
#define CONFIG_FUTEX 1
#define CONFIG_IP_VS_MH_TAB_INDEX 12
#define CONFIG_IP_PNP_DHCP 1
#define CONFIG_GENERIC_PHY_MIPI_DPHY 1
#define CONFIG_UNIX_SCM 1
#define CONFIG_MMC_SPI 1
#define CONFIG_CONSOLE_LOGLEVEL_DEFAULT 7
#define CONFIG_QCOM_HIDMA 1
#define CONFIG_REGMAP_I2C 1
#define CONFIG_GENERIC_SCHED_CLOCK 1
#define CONFIG_ARCH_HAS_FAST_MULTIPLIER 1
#define CONFIG_INPUT_MATRIXKMAP 1
#define CONFIG_USB_G_MULTI_MODULE 1
#define CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG 1
#define CONFIG_HW_RANDOM_OPTEE_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_HL_MODULE 1
#define CONFIG_CRYPTO_USER_API 1
#define CONFIG_RTC_HCTOSYS 1
#define CONFIG_DRM_SIMPLE_BRIDGE_MODULE 1
#define CONFIG_HAVE_ARCH_BITREVERSE 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_HUGETLB_PAGE 1
#define CONFIG_HAVE_ARCH_KASAN_HW_TAGS 1
#define CONFIG_CRYPTO_LIB_POLY1305_MODULE 1
#define CONFIG_REGMAP_IRQ 1
#define CONFIG_USB_HID 1
#define CONFIG_LD_ORPHAN_WARN_LEVEL "warn"
#define CONFIG_RODATA_FULL_DEFAULT_ENABLED 1
#define CONFIG_VSOCKETS_DIAG_MODULE 1
#define CONFIG_NF_TABLES_MODULE 1
#define CONFIG_SLUB_DEBUG 1
#define CONFIG_IP_SET_BITMAP_IP_MODULE 1
#define CONFIG_USB_F_RNDIS_MODULE 1
#define CONFIG_DMADEVICES 1
#define CONFIG_PAHOLE_VERSION 0
#define CONFIG_NF_CONNTRACK_EVENTS 1
#define CONFIG_PINCTRL 1
#define CONFIG_ARCH_SUPPORTS_CFI_CLANG 1
#define CONFIG_IPV6_NDISC_NODETYPE 1
#define CONFIG_NLS_CODEPAGE_1251_MODULE 1
#define CONFIG_FANOTIFY 1
#define CONFIG_SUN50I_H616_CCU 1
#define CONFIG_IP_VS_PROTO_SCTP 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLABEL_MODULE 1
#define CONFIG_ARCH_WANT_DEFAULT_BPF_JIT 1
#define CONFIG_ASYNC_TX_ENABLE_CHANNEL_SWITCH 1
#define CONFIG_CGROUP_SCHED 1
#define CONFIG_QUEUED_RWLOCKS 1
#define CONFIG_SYSVIPC 1
#define CONFIG_RAID6_PQ_BENCHMARK 1
#define CONFIG_ARCH_HAS_GIGANTIC_PAGE 1
#define CONFIG_USB_CONFIGFS_ECM_SUBSET 1
#define CONFIG_HAVE_DEBUG_KMEMLEAK 1
#define CONFIG_SMSC911X 1
#define CONFIG_ARM_GIC_V3_ITS 1
#define CONFIG_RT2X00_MODULE 1
#define CONFIG_NLS_CODEPAGE_863_MODULE 1
#define CONFIG_USB_G_HID_MODULE 1
#define CONFIG_KEYBOARD_GPIO 1
#define CONFIG_NF_CONNTRACK_FTP_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_64KB 1
#define CONFIG_USB_MUSB_SUNXI_MODULE 1
#define CONFIG_MODULES 1
#define CONFIG_RPMSG 1
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#define CONFIG_USB_GADGET 1
#define CONFIG_CONTEXT_TRACKING 1
#define CONFIG_CRYPTO_SHA512_ARM64_CE 1
#define CONFIG_GENERIC_IRQ_IPI 1
#define CONFIG_IOMMU_IOVA 1
#define CONFIG_DUMMY_CONSOLE_COLUMNS 80
#define CONFIG_USB_ETH_RNDIS 1
#define CONFIG_XXHASH 1
#define CONFIG_SOUND_MODULE 1
#define CONFIG_NFT_MASQ_MODULE 1
#define CONFIG_NFT_QUOTA_MODULE 1
#define CONFIG_ARCH_SUNXI 1
#define CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_ARM64_ERRATUM_2051678 1
#define CONFIG_CPU_IDLE_MULTIPLE_DRIVERS 1
#define CONFIG_ARCH_HIBERNATION_POSSIBLE 1
#define CONFIG_ARCH_USE_SYM_ANNOTATIONS 1
#define CONFIG_UNIX 1
#define CONFIG_USB_NET_DRIVERS 1
#define CONFIG_CC_CAN_LINK 1
#define CONFIG_LD_IS_BFD 1
#define CONFIG_AXP20X_POWER 1
#define CONFIG_NO_HZ_COMMON 1
#define CONFIG_MINIX_FS 1
#define CONFIG_DRM_MIPI_DSI 1
#define CONFIG_HAVE_CLK 1
#define CONFIG_CRYPTO_HASH2 1
#define CONFIG_MMC_SDHCI_F_SDH30 1
#define CONFIG_NET_VENDOR_VERTEXCOM 1
#define CONFIG_THERMAL_GOV_STEP_WISE 1
#define CONFIG_BT_HCIBTUSB_POLL_SYNC 1
#define CONFIG_DEFAULT_HOSTNAME "(none)"
#define CONFIG_NLS_KOI8_R_MODULE 1
#define CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS 2
#define CONFIG_NEED_KVM_DIRTY_RING_WITH_BITMAP 1
#define CONFIG_CC_HAS_NO_PROFILE_FN_ATTR 1
#define CONFIG_IP_SET_HASH_NETPORTNET_MODULE 1
#define CONFIG_CPU_FREQ_GOV_POWERSAVE_MODULE 1
#define CONFIG_NFS_FS 1
#define CONFIG_MEDIA_SUPPORT_FILTER 1
#define CONFIG_SUNXI_SRAM 1
#define CONFIG_SUN8I_DE2_CCU 1
#define CONFIG_USB_NET_SMSC95XX_MODULE 1
#define CONFIG_CRASH_DUMP 1
#define CONFIG_MEMBARRIER 1
#define CONFIG_CEC_CORE_MODULE 1
#define CONFIG_CROS_EC_TYPEC_MODULE 1
#define CONFIG_XPS 1
#define CONFIG_INET_ESP_MODULE 1
#define CONFIG_SGL_ALLOC 1
#define CONFIG_LZ4_DECOMPRESS 1
#define CONFIG_NF_TPROXY_IPV6_MODULE 1
#define CONFIG_NF_CONNTRACK_ZONES 1
#define CONFIG_SUNXI_NMI_INTC 1
#define CONFIG_FONT_SUPPORT 1
#define CONFIG_ADVISE_SYSCALLS 1
#define CONFIG_MD 1
#define CONFIG_CRYPTO_ALGAPI 1
#define CONFIG_GENERIC_IRQ_SHOW_LEVEL 1
#define CONFIG_ARM64_ERRATUM_1463225 1
#define CONFIG_HOTPLUG_CORE_SYNC 1
#define CONFIG_ZSWAP_ZPOOL_DEFAULT_ZBUD 1
#define CONFIG_BSD_PROCESS_ACCT_V3 1
#define CONFIG_DRM_PANEL_SIMPLE_MODULE 1
#define CONFIG_NET_VENDOR_WIZNET 1
#define CONFIG_USB_G_DBGP_MODULE 1
#define CONFIG_BRIDGE_MODULE 1
#define CONFIG_PER_VMA_LOCK_STATS 1
#define CONFIG_NETFILTER_XT_MATCH_CGROUP_MODULE 1
#define CONFIG_EEPROM_AT25_MODULE 1
#define CONFIG_SCHED_MM_CID 1
#define CONFIG_RD_BZIP2 1
#define CONFIG_ARM64_HW_AFDBM 1
#define CONFIG_WANT_DEV_COREDUMP 1
#define CONFIG_INPUT_UINPUT_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CHECKSUM_MODULE 1
#define CONFIG_HAVE_ARM_SMCCC_DISCOVERY 1
#define CONFIG_SKB_EXTENSIONS 1
#define CONFIG_PM_OPP 1
#define CONFIG_GPIO_CDEV 1
#define CONFIG_CRYPTO_SHA2_ARM64_CE 1
#define CONFIG_CC_VERSION_TEXT "gcc (GCC) 12.1.0"
#define CONFIG_KEYBOARD_ATKBD 1
#define CONFIG_IIO_ST_MAGN_I2C_3AXIS_MODULE 1
#define CONFIG_NET_IP_TUNNEL_MODULE 1
#define CONFIG_MTD_CFI_I1 1
#define CONFIG_NF_NAT_MODULE 1
#define CONFIG_LEDS_PWM 1
#define CONFIG_BLOCK_LEGACY_AUTOLOAD 1
#define CONFIG_BLK_DEV_INTEGRITY 1
#define CONFIG_CPU_IDLE 1
#define CONFIG_WLAN_VENDOR_INTERSIL 1
#define CONFIG_IP6_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_NF_TABLES_INET 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_REGULATOR 1
#define CONFIG_SND_SOC_MSM8916_WCD_DIGITAL_MODULE 1
#define CONFIG_NF_TABLES_IPV6 1
#define CONFIG_FAIR_GROUP_SCHED 1
#define CONFIG_RT2800USB_MODULE 1
#define CONFIG_BATTERY_SBS_MODULE 1
#define CONFIG_CRYPTO_HASH 1
#define CONFIG_DRM_SUN8I_MIXER 1
#define CONFIG_EFI_PARTITION 1
#define CONFIG_TCG_TIS_I2C_INFINEON 1
#define CONFIG_LOG_BUF_SHIFT 17
#define CONFIG_SYSCON_REBOOT_MODE 1
#define CONFIG_WLAN_VENDOR_ATH 1
#define CONFIG_USB_RTL8153_ECM_MODULE 1
#define CONFIG_NLS_CODEPAGE_857_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_DSCP_MODULE 1
#define CONFIG_EXTRA_FIRMWARE ""
#define CONFIG_TCG_TPM 1
#define CONFIG_NET_VENDOR_8390 1
#define CONFIG_HAVE_KCSAN_COMPILER 1
#define CONFIG_VFAT_FS 1
#define CONFIG_NF_FLOW_TABLE_INET_MODULE 1
#define CONFIG_PID_NS 1
#define CONFIG_SND_SOC_DMIC_MODULE 1
#define CONFIG_REGULATOR_S2MPS11 1
#define CONFIG_PSI 1
#define CONFIG_KEXEC 1
#define CONFIG_MEDIA_PLATFORM_DRIVERS 1
#define CONFIG_CRC32_SLICEBY8 1
#define CONFIG_ARM64_PTR_AUTH_KERNEL 1
#define CONFIG_USB_LIBCOMPOSITE_MODULE 1
#define CONFIG_CRYPTO_SM3 1
#define CONFIG_CPU_RMAP 1
#define CONFIG_SND_HWDEP_MODULE 1
#define CONFIG_SUN50I_A64_CCU 1
#define CONFIG_BLK_DEV_LOOP 1
#define CONFIG_ARCH_HIBERNATION_HEADER 1
#define CONFIG_SPI_MEM 1
#define CONFIG_ARM64_ERRATUM_843419 1
#define CONFIG_NF_NAT_IRC_MODULE 1
#define CONFIG_RTC_DRV_PL031 1
#define CONFIG_INPUT_MISC 1
#define CONFIG_INPUT_VIVALDIFMAP 1
#define CONFIG_MULTIUSER 1
#define CONFIG_DMA_OF 1
#define CONFIG_SUSPEND 1
#define CONFIG_GENERIC_VDSO_TIME_NS 1
#define CONFIG_CROSS_MEMORY_ATTACH 1
#define CONFIG_CRYPTO_CBC 1
#define CONFIG_MEDIA_CONTROLLER 1
#define CONFIG_NETFILTER_XT_TARGET_HMARK_MODULE 1
#define CONFIG_MRP_MODULE 1
#define CONFIG_PINCTRL_SUNXI 1
#define CONFIG_IP6_NF_MATCH_RT_MODULE 1
#define CONFIG_SQUASHFS_DECOMP_SINGLE 1
#define CONFIG_SERIAL_8250_RUNTIME_UARTS 4
#define CONFIG_PREEMPT_BUILD 1
#define CONFIG_CRYPTO_CHACHA20_NEON_MODULE 1
#define CONFIG_CLANG_VERSION 0
#define CONFIG_FS_MBCACHE 1
#define CONFIG_SUNXI_RSB 1
#define CONFIG_RTC_CLASS 1
#define CONFIG_CRC7 1
#define CONFIG_CRYPTO_RNG_DEFAULT 1
#define CONFIG_IP_VS_PROTO_ESP 1
#define CONFIG_F2FS_FS_LZO 1
#define CONFIG_TMPFS_XATTR 1
#define CONFIG_ARM64_ERRATUM_1742098 1
#define CONFIG_NETFILTER_FAMILY_ARP 1
#define CONFIG_ARM_AMBA 1
#define CONFIG_CPU_PM 1
#define CONFIG_V4L2_FWNODE 1
#define CONFIG_CRYPTO_KDF800108_CTR 1
#define CONFIG_QCOM_FALKOR_ERRATUM_1003 1
#define CONFIG_CFG80211_USE_KERNEL_REGDB_KEYS 1
#define CONFIG_TIMER_OF 1
#define CONFIG_NLS_ISO8859_5_MODULE 1
#define CONFIG_IP_VS_WLC_MODULE 1
#define CONFIG_ARCH_HAS_DMA_PREP_COHERENT 1
#define CONFIG_HAVE_FUNCTION_TRACER 1
#define CONFIG_GENERIC_PHY 1
#define CONFIG_CPU_ISOLATION 1
#define CONFIG_NF_NAT_TFTP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MULTIPORT_MODULE 1
#define CONFIG_MTD_SPI_NOR 1
#define CONFIG_SCHED_THERMAL_PRESSURE 1
#define CONFIG_FW_LOADER_COMPRESS_XZ 1
#define CONFIG_NFSD_V4 1
#define CONFIG_ARM64_ERRATUM_2645198 1
#define CONFIG_NETFILTER_XT_TARGET_REDIRECT_MODULE 1
#define CONFIG_CRYPTO_MANAGER2 1
#define CONFIG_SERIAL_8250_DEPRECATED_OPTIONS 1
#define CONFIG_USB_GADGET_VBUS_DRAW 2
#define CONFIG_ARCH_HAS_PTE_SPECIAL 1
#define CONFIG_ARM64_AS_HAS_MTE 1
#define CONFIG_KEXEC_FILE 1
#define CONFIG_NF_NAT_MASQUERADE 1
#define CONFIG_PM_GENERIC_DOMAINS_OF 1
#define CONFIG_CLZ_TAB 1
#define CONFIG_TYPEC_FUSB302_MODULE 1
#define CONFIG_BRIDGE_EBT_DNAT_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_IMAGE_VERIFY_SIG 1
#define CONFIG_GENERIC_PCI_IOMAP 1
#define CONFIG_NETFILTER_XT_TARGET_LOG_MODULE 1
#define CONFIG_SLUB 1
#define CONFIG_CONFIGFS_FS 1
#define CONFIG_XZ_DEC_BCJ 1
#define CONFIG_SLIP_MODULE 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG_THIN 1
#define CONFIG_PM_SLEEP 1
#define CONFIG_F2FS_FS_XATTR 1
#define CONFIG_I2C 1
#define CONFIG_IP_VS_TWOS_MODULE 1
#define CONFIG_ZSWAP_ZPOOL_DEFAULT "zbud"
#define CONFIG_ARM64_ERRATUM_2457168 1
#define CONFIG_PPP_MULTILINK 1
#define CONFIG_ARM64_WORKAROUND_SPECULATIVE_AT 1
#define CONFIG_MMU_GATHER_TABLE_FREE 1
#define CONFIG_BINFMT_SCRIPT 1
#define CONFIG_MOUSE_PS2_CYPRESS 1
#define CONFIG_ARM64_WORKAROUND_TSB_FLUSH_FAILURE 1
#define CONFIG_PINCTRL_SUN50I_A100_R 1
#define CONFIG_FRAME_POINTER 1
#define CONFIG_BT_HIDP_MODULE 1
#define CONFIG_MOUSE_PS2_LOGIPS2PP 1
#define CONFIG_MFD_BD9571MWV 1
#define CONFIG_TICK_CPU_ACCOUNTING 1
#define CONFIG_VM_EVENT_COUNTERS 1
#define CONFIG_PINCTRL_SUN50I_H6 1
#define CONFIG_RESET_SUNXI 1
#define CONFIG_CRYPTO_ECB 1
#define CONFIG_WLAN_VENDOR_BROADCOM 1
#define CONFIG_PM_STD_PARTITION ""
#define CONFIG_SQUASHFS_LZO 1
#define CONFIG_I2C_SLAVE 1
#define CONFIG_NF_CONNTRACK_AMANDA_MODULE 1
#define CONFIG_DEBUG_FS 1
#define CONFIG_USB_FUNCTIONFS_RNDIS 1
#define CONFIG_NET_VENDOR_AMD 1
#define CONFIG_BASE_FULL 1
#define CONFIG_FB_CFB_IMAGEBLIT 1
#define CONFIG_ZLIB_DEFLATE 1
#define CONFIG_NFT_REJECT_INET_MODULE 1
#define CONFIG_SUNRPC 1
#define CONFIG_BATTERY_BQ27XXX 1
#define CONFIG_ARCH_USES_HIGH_VMA_FLAGS 1
#define CONFIG_CACHESTAT_SYSCALL 1
#define CONFIG_RSEQ 1
#define CONFIG_NLS_CODEPAGE_864_MODULE 1
#define CONFIG_IIO_BUFFER 1
#define CONFIG_IP_VS_LBLCR_MODULE 1
#define CONFIG_FW_LOADER 1
#define CONFIG_USB_G_DBGP_SERIAL 1
#define CONFIG_IP6_NF_NAT_MODULE 1
#define CONFIG_KALLSYMS 1
#define CONFIG_COMMON_CLK 1
#define CONFIG_STACKPROTECTOR_STRONG 1
#define CONFIG_RTC_HCTOSYS_DEVICE "rtc0"
#define CONFIG_HAVE_ARCH_COMPILER_H 1
#define CONFIG_NET_VENDOR_FUNGIBLE 1
#define CONFIG_CONTIG_ALLOC 1
#define CONFIG_PWM 1
#define CONFIG_NETFILTER_XT_MATCH_RECENT_MODULE 1
#define CONFIG_NET_VENDOR_ASIX 1
#define CONFIG_DECOMPRESS_XZ 1
#define CONFIG_SERIAL_DEV_CTRL_TTYPORT 1
#define CONFIG_BT_BCM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_PKTTYPE_MODULE 1
#define CONFIG_MII 1
#define CONFIG_MD_BITMAP_FILE 1
#define CONFIG_SIGNALFD 1
#define CONFIG_NET_CORE 1
#define CONFIG_MOUSE_PS2_ALPS 1
#define CONFIG_BPF_JIT_DEFAULT_ON 1
#define CONFIG_KEXEC_CORE 1
#define CONFIG_EXT4_FS 1
#define CONFIG_BRIDGE_EBT_802_3_MODULE 1
#define CONFIG_UNINLINE_SPIN_UNLOCK 1
#define CONFIG_MFD_SEC_CORE 1
#define CONFIG_HAVE_HW_BREAKPOINT 1
#define CONFIG_SND_JACK_INPUT_DEV 1
#define CONFIG_CRYPTO_SHA1 1
#define CONFIG_ARM_PSCI_CPUIDLE_DOMAIN 1
#define CONFIG_TOUCHSCREEN_SUN4I_MODULE 1
#define CONFIG_COMMON_CLK_XGENE 1
#define CONFIG_DRM_I2C_ADV7511_CEC 1
#define CONFIG_WIREGUARD_MODULE 1
#define CONFIG_NLS_KOI8_U_MODULE 1
#define CONFIG_CRC8 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT 1
#define CONFIG_USB_BELKIN 1
#define CONFIG_SATA_PMP 1
#define CONFIG_XZ_DEC 1
#define CONFIG_ATH_COMMON_MODULE 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_NET_VENDOR_ALACRITECH 1
#define CONFIG_BRIDGE_EBT_MARK_T_MODULE 1
#define CONFIG_CRYPTO_DEV_ALLWINNER 1
#define CONFIG_WATCHDOG 1
#define CONFIG_CC_HAVE_SHADOW_CALL_STACK 1
#define CONFIG_HAS_IOMEM 1
#define CONFIG_SND_RAWMIDI_MODULE 1
#define CONFIG_NF_LOG_IPV6_MODULE 1
#define CONFIG_CRYPTO_RSA 1
#define CONFIG_DMA_DIRECT_REMAP 1
#define CONFIG_VALIDATE_FS_PARSER 1
#define CONFIG_IP_VS_OVF_MODULE 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_CRYPTO_SIG2 1
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#define CONFIG_PWRSEQ_EMMC 1
#define CONFIG_HAVE_MOVE_PUD 1
#define CONFIG_VIDEOMODE_HELPERS 1
#define CONFIG_QCOM_EMAC_MODULE 1
#define CONFIG_CRYPTO_ACOMP2 1
#define CONFIG_VHOST_TASK 1
#define CONFIG_ARM64_ERRATUM_2054223 1
#define CONFIG_KEYBOARD_ADC 1
#define CONFIG_NETFILTER_XT_TARGET_TRACE_MODULE 1
#define CONFIG_ARCH_HAS_SETUP_DMA_OPS 1
#define CONFIG_HAVE_ARCH_KASAN_VMALLOC 1
#define CONFIG_MODULE_COMPRESS_XZ 1
#define CONFIG_SUNXI_MBUS 1
#define CONFIG_MTD_MAP_BANK_WIDTH_1 1
#define CONFIG_NUMA 1
#define CONFIG_IP6_NF_MATCH_FRAG_MODULE 1
#define CONFIG_ANDROID_BINDER_DEVICES "binder,hwbinder,vndbinder"
#define CONFIG_SCHED_HRTICK 1
#define CONFIG_EPOLL 1
#define CONFIG_CRYPTO_LZO 1
#define CONFIG_SND_PCM_MODULE 1
#define CONFIG_REGULATOR_HI6421V530 1
#define CONFIG_BRIDGE_EBT_SNAT_MODULE 1
#define CONFIG_APERTURE_HELPERS 1
#define CONFIG_FAILOVER 1
#define CONFIG_NETFILTER_XT_MATCH_DCCP_MODULE 1
#define CONFIG_CGROUP_HUGETLB 1
#define CONFIG_USB_U_ETHER_MODULE 1
#define CONFIG_BT_BNEP_MC_FILTER 1
#define CONFIG_CRYPTO_CRC32_MODULE 1
#define CONFIG_KEYBOARD_MAX7359_MODULE 1
#define CONFIG_NLS_CODEPAGE_852_MODULE 1
#define CONFIG_CRYPTO_CRCT10DIF_ARM64_CE 1
#define CONFIG_SERIAL_XILINX_PS_UART 1
#define CONFIG_NETFILTER_XT_MATCH_COMMENT_MODULE 1
#define CONFIG_GENERIC_PTDUMP 1
#define CONFIG_AS_HAS_ARMV8_5 1
#define CONFIG_USB_NET_RNDIS_HOST_MODULE 1
#define CONFIG_NET 1
#define CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE 1
#define CONFIG_USB_CHIPIDEA_NPCM 1
#define CONFIG_INPUT_EVDEV 1
#define CONFIG_SND_JACK 1
#define CONFIG_LEDS_SGM3140_MODULE 1
#define CONFIG_COMMON_CLK_SCPI 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_PATTERN 1
#define CONFIG_NETFILTER_XT_TARGET_TCPMSS_MODULE 1
#define CONFIG_EXT2_FS 1
#define CONFIG_NETFILTER_XT_MATCH_DSCP_MODULE 1
#define CONFIG_SND_SUN4I_I2S_MODULE 1
#define CONFIG_CRYPTO_LIB_BLAKE2S_GENERIC 1
#define CONFIG_NETFILTER_XT_MATCH_CONNTRACK_MODULE 1
#define CONFIG_ARM_ARCH_TIMER_EVTSTREAM 1
#define CONFIG_ARM64_ERRATUM_2441007 1
#define CONFIG_NETFILTER_XT_MATCH_RATEEST_MODULE 1
#define CONFIG_PWRSEQ_SIMPLE 1
#define CONFIG_SND_ALOOP_MODULE 1
#define CONFIG_SND_AUDIO_GRAPH_CARD_MODULE 1
#define CONFIG_PINMUX 1
#define CONFIG_IRQ_DOMAIN_HIERARCHY 1
#define CONFIG_ATA_FORCE 1
#define CONFIG_NETFILTER_BPF_LINK 1
#define CONFIG_HW_RANDOM_ARM_SMCCC_TRNG_MODULE 1
#define CONFIG_MPILIB 1
#define CONFIG_USB_NET_CDCETHER_MODULE 1
#define CONFIG_PACKET 1
#define CONFIG_XFRM_ALGO 1
#define CONFIG_PL330_DMA 1
#define CONFIG_SND_SIMPLE_CARD_UTILS_MODULE 1
#define CONFIG_NF_CONNTRACK_TIMESTAMP 1
#define CONFIG_HAVE_CLK_PREPARE 1
#define CONFIG_CRYPTO_AKCIPHER2 1
#define CONFIG_NODES_SHIFT 2
#define CONFIG_NETFILTER_XT_MATCH_IPRANGE_MODULE 1
#define CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE 1
#define CONFIG_FB_IOMEM_FOPS 1
#define CONFIG_SND_CTL_FAST_LOOKUP 1
#define CONFIG_MMC_SDHCI_XENON 1
#define CONFIG_ARCH_WANT_PMD_MKWRITE 1
#define CONFIG_CRYPTO_SM3_ARM64_CE 1
#define CONFIG_BTRFS_FS_POSIX_ACL 1
#define CONFIG_CRYPTO_JITTERENTROPY_OSR 1
#define CONFIG_NET_VENDOR_ALLWINNER 1
#define CONFIG_ARM64_WORKAROUND_SPECULATIVE_UNPRIV_LOAD 1
#define CONFIG_DUMMY_CONSOLE_ROWS 25
#define CONFIG_USB_XHCI_PLATFORM 1
#define CONFIG_NF_CONNTRACK_TFTP_MODULE 1
#define CONFIG_NFS_V3 1
#define CONFIG_HAVE_KVM_IRQFD 1
#define CONFIG_NLS_CODEPAGE_949_MODULE 1
#define CONFIG_XEN_XENBUS_FRONTEND 1
#define CONFIG_INET 1
#define CONFIG_XZ_DEC_POWERPC 1
#define CONFIG_ARM64_MTE 1
#define CONFIG_IP_PNP_BOOTP 1
#define CONFIG_USB_MUSB_HDRC 1
#define CONFIG_NETFILTER_XT_MATCH_ADDRTYPE_MODULE 1
#define CONFIG_NET_VENDOR_HUAWEI 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_USB_NET_MCS7830_MODULE 1
#define CONFIG_DRM_DW_HDMI 1
#define CONFIG_FREEZER 1
#define CONFIG_USB_F_SUBSET_MODULE 1
#define CONFIG_BT_MODULE 1
#define CONFIG_REBOOT_MODE 1
#define CONFIG_ARM64_4K_PAGES 1
#define CONFIG_NFT_QUEUE_MODULE 1
#define CONFIG_LZ4HC_COMPRESS_MODULE 1
#define CONFIG_BRIDGE_EBT_BROUTE_MODULE 1
#define CONFIG_USB_NET_SMSC75XX_MODULE 1
#define CONFIG_HAVE_ARCH_VMAP_STACK 1
#define CONFIG_NETFILTER_XT_MATCH_IPVS_MODULE 1
#define CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN "kernel.org"
#define CONFIG_BT_LE_L2CAP_ECRED 1
#define CONFIG_IP_SET_MAX 256
#define CONFIG_USB_F_ACM_MODULE 1
#define CONFIG_ARM64_ERRATUM_1319367 1
#define CONFIG_RTC_LIB 1
#define CONFIG_FW_LOADER_PAGED_BUF 1
#define CONFIG_NETFILTER_XT_MATCH_POLICY_MODULE 1
#define CONFIG_ARM64_ERRATUM_826319 1
#define CONFIG_HAVE_KPROBES 1
#define CONFIG_NUMA_BALANCING_DEFAULT_ENABLED 1
#define CONFIG_MOUSE_PS2_SYNAPTICS_SMBUS 1
#define CONFIG_IP_ROUTE_CLASSID 1
#define CONFIG_NETFILTER_XT_TARGET_TEE_MODULE 1
#define CONFIG_CRYPTO_AES 1
#define CONFIG_HAVE_GENERIC_VDSO 1
#define CONFIG_BACKLIGHT_LP855X 1
#define CONFIG_GPIOLIB 1
#define CONFIG_ARCH_WANT_DEFAULT_TOPDOWN_MMAP_LAYOUT 1
#define CONFIG_FUTEX_PI 1
#define CONFIG_BMC150_ACCEL_SPI_MODULE 1
#define CONFIG_MMC_DW 1
#define CONFIG_GENERIC_CPU_VULNERABILITIES 1
#define CONFIG_NFT_LIMIT_MODULE 1
#define CONFIG_AUTOFS_FS 1
#define CONFIG_SND_SUN8I_ADDA_PR_REGMAP_MODULE 1
#define CONFIG_NETFILTER_XT_NAT_MODULE 1
#define CONFIG_BT_HCIUART_H4 1
#define CONFIG_DMA_NONCOHERENT_MMAP 1
#define CONFIG_RTC_DRV_DS3232 1
#define CONFIG_CLKSRC_MMIO 1
#define CONFIG_BACKLIGHT_LED_MODULE 1
#define CONFIG_ARM_ARCH_TIMER_OOL_WORKAROUND 1
#define CONFIG_NET_VENDOR_AQUANTIA 1
#define CONFIG_NF_CONNTRACK_MARK 1
#define CONFIG_NETFILTER 1
#define CONFIG_NFT_REJECT_IPV4_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HASHLIMIT_MODULE 1
#define CONFIG_BRIDGE_EBT_AMONG_MODULE 1
#define CONFIG_HAVE_ARCH_KASAN 1
#define CONFIG_NET_VENDOR_SMSC 1
#define CONFIG_CAVIUM_ERRATUM_23154 1
#define CONFIG_NETFILTER_NETLINK_ACCT_MODULE 1
#define CONFIG_GENERIC_ARCH_TOPOLOGY 1
#define CONFIG_NFS_DISABLE_UDP_SUPPORT 1
#define CONFIG_NETFILTER_XT_MATCH_CLUSTER_MODULE 1
#define CONFIG_F2FS_FS_COMPRESSION 1
#define CONFIG_NLS_CODEPAGE_950_MODULE 1
#define CONFIG_CLONE_BACKWARDS 1
#define CONFIG_HAVE_NMI 1
#define CONFIG_BT_BNEP_MODULE 1
#define CONFIG_POWER_RESET_XGENE 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_NFT_REJECT_NETDEV_MODULE 1
#define CONFIG_RD_XZ 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC_KEY 1
#define CONFIG_REGULATOR_VCTRL_MODULE 1
#define CONFIG_PREEMPT_RCU 1
#define CONFIG_DEVFREQ_THERMAL 1
#define CONFIG_CRYPTO_ECDH_MODULE 1
#define CONFIG_PINCTRL_SUN50I_A64 1
#define CONFIG_ATA_VERBOSE_ERROR 1
#define CONFIG_NF_CONNTRACK_SNMP_MODULE 1
#define CONFIG_SND_DRIVERS 1
#define CONFIG_NLS_MAC_GREEK_MODULE 1
#define CONFIG_NET_FLOW_LIMIT 1
#define CONFIG_USB_ULPI_VIEWPORT 1
#define CONFIG_LOCKDEP_SUPPORT 1
#define CONFIG_NLS_CODEPAGE_869_MODULE 1
#define CONFIG_IP6_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_NFT_REDIR_MODULE 1
#define CONFIG_USB_CHIPIDEA_IMX 1
#define CONFIG_CRYPTO_LIB_CURVE25519_GENERIC_MODULE 1
#define CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION 1
#define CONFIG_ARCH_WANT_HUGE_PMD_SHARE 1
#define CONFIG_NFT_TUNNEL_MODULE 1
#define CONFIG_POSIX_MQUEUE 1
#define CONFIG_CC_HAS_WORKING_NOSANITIZE_ADDRESS 1
#define CONFIG_NETFILTER_INGRESS 1
#define CONFIG_CRYPTO_LIB_GF128MUL 1
#define CONFIG_GPIO_DWAPB 1
#define CONFIG_CAVIUM_ERRATUM_27456 1
#define CONFIG_USB_DWC3_OF_SIMPLE 1
#define CONFIG_PINCTRL_MAX77620 1
#define CONFIG_ARM_SMMU_V3 1
#define CONFIG_INPUT_PWM_VIBRA_MODULE 1
#define CONFIG_CPU_FREQ_STAT 1
#define CONFIG_NET_XGRESS 1
#define CONFIG_XEN_PRIVCMD_MODULE 1
#define CONFIG_GENERIC_STRNCPY_FROM_USER 1
#define CONFIG_MEDIA_PLATFORM_SUPPORT 1
#define CONFIG_MTD_BLKDEVS 1
#define CONFIG_HAVE_RSEQ 1
#define CONFIG_NETFILTER_XT_TARGET_NETMAP_MODULE 1
#define CONFIG_ARM64_ERRATUM_858921 1
#define CONFIG_OF_KOBJ 1
#define CONFIG_CONTEXT_TRACKING_IDLE 1
#define CONFIG_SPMI 1
#define CONFIG_NETFILTER_XT_MATCH_SCTP_MODULE 1
#define CONFIG_RTL8723BS_MODULE 1
#define CONFIG_CRASH_CORE 1
#define CONFIG_REGULATOR_MAX77620 1
#define CONFIG_NLS_ISO8859_15_MODULE 1
#define CONFIG_INET6_ESP_MODULE 1
#define CONFIG_IP_VS_WRR_MODULE 1
#define CONFIG_ILLEGAL_POINTER_VALUE 0xdead000000000000
#define CONFIG_GENERIC_GETTIMEOFDAY 1
#define CONFIG_F2FS_IOSTAT 1
#define CONFIG_NETFILTER_XT_SET_MODULE 1
#define CONFIG_NLS_MAC_CROATIAN_MODULE 1
#define CONFIG_PCS_XPCS_MODULE 1
#define CONFIG_SND_SOC_EC25_MODULE 1
#define CONFIG_ARCH_USE_MEMTEST 1
#define CONFIG_TASKSTATS 1
#define CONFIG_DRM_SUN6I_DSI 1
#define CONFIG_NLS_CODEPAGE_932_MODULE 1
#define CONFIG_NLS_MAC_ICELAND_MODULE 1
#define CONFIG_USB_FUNCTIONFS_GENERIC 1
#define CONFIG_PPPOE_HASH_BITS 4
#define CONFIG_NET_VENDOR_PENSANDO 1
#define CONFIG_IP6_NF_FILTER_MODULE 1
#define CONFIG_SYSTEM_DATA_VERIFICATION 1
#define CONFIG_NEED_DMA_MAP_STATE 1
#define CONFIG_IIO 1
#define CONFIG_SND_HDA_PREALLOC_SIZE 64
#define CONFIG_GARP_MODULE 1
#define CONFIG_SERIO_LIBPS2 1
#define CONFIG_IP_VS_PROTO_TCP 1
#define CONFIG_NETFILTER_XT_MATCH_NFACCT_MODULE 1
#define CONFIG_HAVE_ARCH_KASAN_SW_TAGS 1
#define CONFIG_NETFILTER_XT_MATCH_CONNBYTES_MODULE 1
#define CONFIG_F2FS_FS_LZ4HC 1
#define CONFIG_SENSORS_ARM_SCPI 1
#define CONFIG_FONT_8x8 1
#define CONFIG_SMC91X 1
#define CONFIG_FB_SIMPLE 1
#define CONFIG_RELOCATABLE 1
#define CONFIG_FB_ARMCLCD 1
#define CONFIG_QUEUED_SPINLOCKS 1
#define CONFIG_XOR_BLOCKS_MODULE 1
#define CONFIG_TIME_NS 1
#define CONFIG_CRYPTO_SHA3_ARM64 1
#define CONFIG_PANIC_TIMEOUT -1
#define CONFIG_RT2X00_LIB_MODULE 1
#define CONFIG_USB_DWC2 1
#define CONFIG_HID_BATTERY_STRENGTH 1
#define CONFIG_PM_GENERIC_DOMAINS_SLEEP 1
#define CONFIG_NETFILTER_XT_MATCH_ECN_MODULE 1
#define CONFIG_TYPEC_TCPM_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP 1
#define CONFIG_IP_NF_TARGET_TTL_MODULE 1
#define CONFIG_STACKDEPOT 1
#define CONFIG_CFG80211_DEFAULT_PS 1
#define CONFIG_IIO_ST_PRESS_MODULE 1
#define CONFIG_NET_VENDOR_XILINX 1
#define CONFIG_DECOMPRESS_LZ4 1
#define CONFIG_ARM_SMCCC_SOC_ID 1
#define CONFIG_NETFILTER_NETLINK_OSF_MODULE 1
#define CONFIG_XEN_FBDEV_FRONTEND 1
#define CONFIG_IP6_NF_MATCH_SRH_MODULE 1
#define CONFIG_POWER_RESET_GPIO 1
#define CONFIG_RT2X00_LIB_FIRMWARE 1
#define CONFIG_VIDEO_V4L2_I2C 1
#define CONFIG_BPF_SYSCALL 1
#define CONFIG_SMP 1
#define CONFIG_NET_VENDOR_CADENCE 1
#define CONFIG_NET_VENDOR_MICROSOFT 1
#define CONFIG_TTY 1
#define CONFIG_NETFILTER_XT_MATCH_TIME_MODULE 1
#define CONFIG_IP_VS_MODULE 1
#define CONFIG_TYPEC_TCPCI_MODULE 1
#define CONFIG_ZSMALLOC_MODULE 1
#define CONFIG_NET_VENDOR_I825XX 1
#define CONFIG_NETFILTER_XT_MATCH_MAC_MODULE 1
#define CONFIG_ARM_SMMU 1
#define CONFIG_IOMMU_DMA 1
#define CONFIG_RCU_EXP_CPU_STALL_TIMEOUT 20
#define CONFIG_SND_SUN8I_CODEC_ANALOG_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFLOG_MODULE 1
#define CONFIG_GENERIC_ALLOCATOR 1
#define CONFIG_MMC_SDHCI_IO_ACCESSORS 1
#define CONFIG_FB_SYSMEM_HELPERS_DEFERRED 1
#define CONFIG_SQUASHFS_LZ4 1
#define CONFIG_LIBCRC32C 1
#define CONFIG_KEYBOARD_MATRIX_MODULE 1
#define CONFIG_GENERIC_BUG 1
#define CONFIG_CRYPTO_SHA256 1
#define CONFIG_HAVE_FTRACE_MCOUNT_RECORD 1
#define CONFIG_BRIDGE_VLAN_FILTERING 1
#define CONFIG_WL18XX_MODULE 1
#define CONFIG_ARM_SUN8I_A33_MBUS_DEVFREQ_MODULE 1
#define CONFIG_POSIX_TIMERS 1
#define CONFIG_INET_TCP_DIAG 1
#define CONFIG_HOTPLUG_CORE_SYNC_DEAD 1
#define CONFIG_HW_CONSOLE 1
#define CONFIG_MDIO_BITBANG 1
#define CONFIG_ZSMALLOC_CHAIN_SIZE 8
#define CONFIG_HAVE_KVM_IRQ_ROUTING 1
#define CONFIG_RAS 1
#define CONFIG_DWMAC_SUNXI_MODULE 1
#define CONFIG_USB_ETH_EEM 1
#define CONFIG_SMSC_PHY_MODULE 1
#define CONFIG_DEVMEM 1
#define CONFIG_MOUSE_PS2_FOCALTECH 1
#define CONFIG_ARM_PMU 1
#define CONFIG_CRYPTO_LIB_SHA1 1
#define CONFIG_SND_SPI 1
#define CONFIG_NFT_LOG_MODULE 1
#define CONFIG_BRIDGE_EBT_IP_MODULE 1
#define CONFIG_HID_MONTEREY 1
#define CONFIG_FB_UDL_MODULE 1
#define CONFIG_ARCH_USES_PG_ARCH_X 1
#define CONFIG_HID_EZKEY 1
#define CONFIG_SND_SUN9I_HDMI_AUDIO_MODULE 1
#define CONFIG_VIDEO_SUNXI_CEDRUS 1
#define CONFIG_HAVE_UID16 1
#define CONFIG_COMPAT_OLD_SIGACTION 1
#define CONFIG_KEYBOARD_SUN4I_LRADC_MODULE 1
#define CONFIG_IRQ_MSI_IOMMU 1
#define CONFIG_RTC_NVMEM 1
#define CONFIG_BACKLIGHT_PWM 1
#define CONFIG_QUOTACTL 1
#define CONFIG_V4L2_MEM2MEM_DEV 1
#define CONFIG_PARAVIRT 1
#define CONFIG_WQ_POWER_EFFICIENT_DEFAULT 1
#define CONFIG_NLS_UCS2_UTILS_MODULE 1
#define CONFIG_CRYPTO_CRYPTD 1
#define CONFIG_ZSTD_COMMON 1
#define CONFIG_NF_SOCKET_IPV4_MODULE 1
#define CONFIG_HAVE_IOREMAP_PROT 1
#define CONFIG_BUILTIN_RETURN_ADDRESS_STRIPS_PAC 1
#define CONFIG_CC_HAS_KASAN_GENERIC 1
#define CONFIG_DRM_SUN8I_DW_HDMI 1
#define CONFIG_HAVE_ARM_SMCCC 1
#define CONFIG_INV_MPU6050_IIO_MODULE 1
#define CONFIG_CROS_EC 1
#define CONFIG_LOCALVERSION "-MANJARO-ARM"
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_CPU 1
#define CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK 1
#define CONFIG_ARCH_SUPPORTS_PAGE_TABLE_CHECK 1
#define CONFIG_REGULATOR_QCOM_SPMI 1
#define CONFIG_MEMTEST 1
#define CONFIG_SYMBOLIC_ERRNAME 1
#define CONFIG_CRYPTO 1
#define CONFIG_VIDEO_SUNXI 1
#define CONFIG_I2C_MUX_PCA954x 1
#define CONFIG_BTRFS_FS_MODULE 1
#define CONFIG_DEFAULT_MMAP_MIN_ADDR 4096
#define CONFIG_SYSTEM_TRUSTED_KEYS ""
#define CONFIG_ASYNC_TX_DISABLE_XOR_VAL_DMA 1
#define CONFIG_IP_NF_IPTABLES 1
#define CONFIG_CMDLINE "console=ttyAMA0"
#define CONFIG_VSOCKETS_MODULE 1
#define CONFIG_BT_BNEP_PROTO_FILTER 1
#define CONFIG_USB_CHIPIDEA_HOST 1
#define CONFIG_RUNTIME_TESTING_MENU 1
#define CONFIG_VIDEOBUF2_DMA_CONTIG 1
#define CONFIG_USB_XHCI_HCD 1
#define CONFIG_MMC_SDHCI_OF_ARASAN 1
#define CONFIG_IP_SET_LIST_SET_MODULE 1
#define CONFIG_HW_PERF_EVENTS 1
#define CONFIG_NET_SELFTESTS 1
#define CONFIG_GPIO_GENERIC_PLATFORM 1
#define CONFIG_PLATFORM_MHU 1
#define CONFIG_DMA_VIRTUAL_CHANNELS 1
#define CONFIG_ZSWAP_COMPRESSOR_DEFAULT "lzo"
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_STRICT_DEVMEM 1
#define CONFIG_GENERIC_IRQ_SHOW 1
#define CONFIG_I2C_MV64XXX 1
#define CONFIG_NVMEM_SYSFS 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL_RELATIVE 1
#define CONFIG_ARCH_HAS_ELF_RANDOMIZE 1
#define CONFIG_9P_FS 1
#define CONFIG_NETFS_SUPPORT 1
#define CONFIG_HAVE_FUNCTION_ARG_ACCESS_API 1
#define CONFIG_PANIC_ON_OOPS_VALUE 0
#define CONFIG_NET_VENDOR_SAMSUNG 1
#define CONFIG_NET_VENDOR_ADI 1
#define CONFIG_ZRAM_DEF_COMP "lzo-rle"
#define CONFIG_SUN8I_THERMAL 1
#define CONFIG_INITRAMFS_PRESERVE_MTIME 1
#define CONFIG_BATTERY_BQ27XXX_I2C 1
#define CONFIG_SCSI_MOD 1
#define CONFIG_NET_VENDOR_MICREL 1
#define CONFIG_CRYPTO_ESSIV 1
#define CONFIG_F2FS_FS_POSIX_ACL 1
#define CONFIG_HID_ITE 1
#define CONFIG_HNS 1
#define CONFIG_KEYBOARD_PINEPHONE_MODULE 1
#define CONFIG_LEDS_CLASS_FLASH 1
#define CONFIG_CRYPTO_CRC32C 1
#define CONFIG_SERIAL_CORE 1
#define CONFIG_IIO_ST_SENSORS_I2C_MODULE 1
#define CONFIG_FUSE_FS 1
#define CONFIG_USB_CONFIGFS_SERIAL 1
#define CONFIG_UID16 1
#define CONFIG_HID_MICROSOFT 1
#define CONFIG_EXFAT_DEFAULT_IOCHARSET "utf8"
#define CONFIG_HAVE_KVM_DIRTY_RING 1
#define CONFIG_HAVE_KRETPROBES 1
#define CONFIG_ASSOCIATIVE_ARRAY 1
#define CONFIG_NF_DEFRAG_IPV6_MODULE 1
#define CONFIG_MICREL_PHY 1
#define CONFIG_VIDEO_DEV 1
#define CONFIG_CC_HAS_ZERO_CALL_USED_REGS 1
#define CONFIG_NFS_V4 1
#define CONFIG_RPMSG_QCOM_GLINK_RPM 1
#define CONFIG_PPP_FILTER 1
#define CONFIG_MAILBOX 1
#define CONFIG_INPUT_LEDS 1
#define CONFIG_RCU_NEED_SEGCBLIST 1
#define CONFIG_HAS_DMA 1
#define CONFIG_NF_CT_PROTO_SCTP 1
#define CONFIG_EDAC 1
#define CONFIG_VIDEO_SUN6I_CSI 1
#define CONFIG_SCSI 1
#define CONFIG_CC_HAVE_STACKPROTECTOR_SYSREG 1
#define CONFIG_ARCH_BINFMT_ELF_STATE 1
#define CONFIG_LEDS_TRIGGER_PANIC 1
#define CONFIG_FB_CFB_FILLRECT 1
#define CONFIG_NF_NAT_PPTP_MODULE 1
#define CONFIG_ARM64_ERRATUM_1542419 1
#define CONFIG_HID_CHICONY 1
#define CONFIG_NLS_MAC_ROMAN_MODULE 1
#define CONFIG_HAVE_ARCH_THREAD_STRUCT_WHITELIST 1
#define CONFIG_HID 1
#define CONFIG_CC_HAS_BRANCH_PROT_PAC_RET 1
#define CONFIG_DMA_DECLARE_COHERENT 1
#define CONFIG_AMD_XGBE 1
#define CONFIG_USB_CONFIGFS_F_UAC1 1
#define CONFIG_USB_DWC3_DUAL_ROLE 1
#define CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND 1
#define CONFIG_ARM_MHU 1
#define CONFIG_ANDROID_BINDERFS 1
#define CONFIG_SLIP_SMART 1
#define CONFIG_NLS_ISO8859_9_MODULE 1
#define CONFIG_USB_ARMLINUX 1
#define CONFIG_IP_VS_PE_SIP_MODULE 1
#define CONFIG_LEDS_TRIGGER_DEFAULT_ON 1
#define CONFIG_FONT_8x16 1
#define CONFIG_NET_VENDOR_MELLANOX 1
#define CONFIG_SERIAL_8250_FSL 1
#define CONFIG_VT_CONSOLE_SLEEP 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG 1
#define CONFIG_CRYPTO_USER_API_AEAD 1
#define CONFIG_ARCH_HAS_CURRENT_STACK_POINTER 1
#define CONFIG_PTP_1588_CLOCK 1
#define CONFIG_NF_DUP_NETDEV_MODULE 1
#define CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE 3
#define CONFIG_SQUASHFS_COMPILE_DECOMP_SINGLE 1
#define CONFIG_ARCH_HAS_CACHE_LINE_SIZE 1
#define CONFIG_JBD2 1
#define CONFIG_SPARSEMEM_VMEMMAP 1
#define CONFIG_INET6_IPCOMP_MODULE 1
#define CONFIG_MEMCG_KMEM 1
#define CONFIG_NET_VENDOR_MARVELL 1
#define CONFIG_PHYLIB 1
#define CONFIG_REGULATOR_GPIO 1
#define CONFIG_IPV6_TUNNEL_MODULE 1
#define CONFIG_CRYPTO_SHA256_ARM64 1
#define CONFIG_NLS_CODEPAGE_874_MODULE 1
#define CONFIG_IRQ_DOMAIN 1
#define CONFIG_ARCH_HAS_DEBUG_VIRTUAL 1
#define CONFIG_HAVE_ASM_MODVERSIONS 1
#define CONFIG_IPC_NS 1
#define CONFIG_CRYPTO_LIB_CHACHA20POLY1305_MODULE 1
#define CONFIG_OF_NUMA 1
#define CONFIG_CRYPTO_SHA512_ARM64 1
#define CONFIG_MISC_FILESYSTEMS 1
#define CONFIG_ARCH_MMAP_RND_BITS_MIN 18
#define CONFIG_NETFILTER_XT_MATCH_CONNLIMIT_MODULE 1
#define CONFIG_IP_NF_SECURITY_MODULE 1
#define CONFIG_IP_NF_RAW_MODULE 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG 1
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_SOCKET_MODULE 1
#define CONFIG_LEDS_BRIGHTNESS_HW_CHANGED 1
#define CONFIG_DECOMPRESS_BZIP2 1
#define CONFIG_REGULATOR_AXP20X 1
#define CONFIG_PER_VMA_LOCK 1
#define CONFIG_IIO_ST_SENSORS_CORE_MODULE 1
#define CONFIG_KSM 1
#define CONFIG_ARCH_SUPPORTS_UPROBES 1
#define CONFIG_NET_VENDOR_STMICRO 1
#define CONFIG_OF_DYNAMIC 1
#define CONFIG_NF_NAT_H323_MODULE 1
#define CONFIG_XZ_DEC_SPARC 1
#define CONFIG_USB_NET_QMI_WWAN_MODULE 1
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_DEVICE 1
#define CONFIG_OF_GPIO 1
#define CONFIG_ARCH_SUPPORTS_HUGETLBFS 1
#define CONFIG_SERIAL_MCTRL_GPIO 1
#define CONFIG_REALTEK_PHY_MODULE 1
#define CONFIG_PROC_VMCORE 1
#define CONFIG_HID_A4TECH 1
#define CONFIG_NLS_CODEPAGE_860_MODULE 1
#define CONFIG_VEXPRESS_CONFIG 1
#define CONFIG_NETFILTER_XT_MATCH_ESP_MODULE 1
#define CONFIG_ARM64_ERRATUM_2441009 1
#define CONFIG_IP_NF_TARGET_NETMAP_MODULE 1
#define CONFIG_DST_CACHE 1
#define CONFIG_KVM_GENERIC_HARDWARE_ENABLING 1
#define CONFIG_NF_REJECT_IPV6_MODULE 1
#define CONFIG_RCU_CPU_STALL_TIMEOUT 21
#define CONFIG_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#define CONFIG_BT_HCIUART_BCM 1
#define CONFIG_PINCTRL_SUN8I_H3_R 1
#define CONFIG_INPUT_FF_MEMLESS 1
#define CONFIG_IP_SET_HASH_NET_MODULE 1
#define CONFIG_ARM64_ERRATUM_819472 1
#define CONFIG_LLD_VERSION 0
#define CONFIG_SECTION_MISMATCH_WARN_ONLY 1
#define CONFIG_ARM64_ERRATUM_827319 1
#define CONFIG_NETFILTER_EGRESS 1
#define CONFIG_CAVIUM_TX2_ERRATUM_219 1
#define CONFIG_MDIO_DEVICE 1
#define CONFIG_NEED_SG_DMA_LENGTH 1
#define CONFIG_TIMER_PROBE 1
#define CONFIG_INPUT_AXP20X_PEK 1
#define CONFIG_MODPROBE_PATH "/sbin/modprobe"
#define CONFIG_POWER_RESET 1
#define CONFIG_NF_NAT_AMANDA_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_MODULE 1
#define CONFIG_DRM_DISPLAY_HELPER 1
#define CONFIG_IP6_NF_MATCH_IPV6HEADER_MODULE 1
#define CONFIG_ARM64_EPAN 1
#define CONFIG_MACVLAN_MODULE 1
#define CONFIG_BPF_JIT 1
#define CONFIG_INV_MPU6050_I2C_MODULE 1
#define CONFIG_SENSORS_INA2XX_MODULE 1
#define CONFIG_WLCORE_SDIO_MODULE 1
#define CONFIG_PROFILING 1
#define CONFIG_INTERVAL_TREE 1
#define CONFIG_MMC_DW_PLTFM 1
#define CONFIG_NET_VENDOR_AMAZON 1
#define CONFIG_SPARSEMEM 1
#define CONFIG_BLK_MQ_STACKING 1
#define CONFIG_REGULATOR_FAN53555 1
#define CONFIG_DRM_GEM_SHMEM_HELPER 1
#define CONFIG_VHOST_NET_MODULE 1
#define CONFIG_WLAN_VENDOR_ATMEL 1
#define CONFIG_NET_VENDOR_HISILICON 1
#define CONFIG_GRACE_PERIOD 1
#define CONFIG_SLHC_MODULE 1
#define CONFIG_KEYBOARD_GPIO_POLLED_MODULE 1
#define CONFIG_CRYPTO_MANAGER 1
#define CONFIG_PHY_SAMSUNG_USB2 1
#define CONFIG_ARCH_HAS_SUBPAGE_FAULTS 1
#define CONFIG_PPP_BSDCOMP_MODULE 1
#define CONFIG_EDAC_SUPPORT 1
#define CONFIG_RT_MUTEXES 1
#define CONFIG_LOCK_SPIN_ON_OWNER 1
#define CONFIG_WLCORE_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_MARK_MODULE 1
#define CONFIG_NFT_SYNPROXY_MODULE 1
#define CONFIG_FSL_ERRATUM_A008585 1
#define CONFIG_NVIDIA_CARMEL_CNP_ERRATUM 1
#define CONFIG_CC_NO_ARRAY_BOUNDS 1
#define CONFIG_ATH10K_CE 1
#define CONFIG_DRM_I2C_SIL164_MODULE 1
#define CONFIG_HUGETLBFS 1
#define CONFIG_SLAB_MERGE_DEFAULT 1
#define CONFIG_KERNFS 1
#define CONFIG_I2C_ALGOBIT_MODULE 1
#define CONFIG_MMC_BLOCK 1
#define CONFIG_BATTERY_AXP20X 1
#define CONFIG_KVM 1
#define CONFIG_PAGE_COUNTER 1
#define CONFIG_IOMMU_DEFAULT_DMA_STRICT 1
#define CONFIG_SND_SIMPLE_CARD_MODULE 1
#define CONFIG_MMC_DW_EXYNOS 1
#define CONFIG_CFG80211_CRDA_SUPPORT 1
#define CONFIG_BPFILTER 1
#define CONFIG_WIRELESS 1
#define CONFIG_WEXT_PROC 1
#define CONFIG_CRYPTO_AES_ARM64_CE_BLK 1
#define CONFIG_SQUASHFS 1
#define CONFIG_HZ_250 1
#define CONFIG_CRYPTO_JITTERENTROPY_MEMORY_BLOCKS 64
#define CONFIG_ARCH_HAS_STRICT_KERNEL_RWX 1
#define CONFIG_NFT_DUP_IPV6_MODULE 1
#define CONFIG_LOCK_DEBUGGING_SUPPORT 1
#define CONFIG_BT_HCIBTUSB_MODULE 1
#define CONFIG_PKCS7_MESSAGE_PARSER 1
#define CONFIG_CROS_EC_LIGHTBAR 1
#define CONFIG_TASK_IO_ACCOUNTING 1
#define CONFIG_NF_LOG_SYSLOG_MODULE 1
#define CONFIG_DMA_SUN6I 1
#define CONFIG_FAT_DEFAULT_IOCHARSET "iso8859-1"
#define CONFIG_USB_CONFIGFS_MASS_STORAGE 1
#define CONFIG_FRAME_WARN 2048
#define CONFIG_USB_NET_CDC_NCM_MODULE 1
#define CONFIG_UVC_COMMON_MODULE 1
#define CONFIG_HID_GENERIC 1
#define CONFIG_ARCH_MMAP_RND_BITS 18
#define CONFIG_QCOM_FALKOR_ERRATUM_E1041 1
#define CONFIG_USB_ETH_MODULE 1
#define CONFIG_ARM64_ERRATUM_1530923 1
#define CONFIG_GENERIC_HWEIGHT 1
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_RTL_CARDS_MODULE 1
#define CONFIG_POWER_RESET_GPIO_RESTART 1
#define CONFIG_PAGE_POOL_STATS 1
#define CONFIG_ARCH_MHP_MEMMAP_ON_MEMORY_ENABLE 1
#define CONFIG_TASKS_TRACE_RCU 1
#define CONFIG_CGROUPS 1
#define CONFIG_MFD_AXP20X 1
#define CONFIG_MMC 1
#define CONFIG_LZO_COMPRESS 1
#define CONFIG_GUEST_PERF_EVENTS 1
#define CONFIG_HAVE_ARCH_MMAP_RND_COMPAT_BITS 1
#define CONFIG_CRYPTO_SEQIV_MODULE 1
#define CONFIG_BRCMFMAC_MODULE 1
#define CONFIG_HID_LOGITECH 1
#define CONFIG_CRYPTO_USER_API_RNG 1
#define CONFIG_HAVE_GCC_PLUGINS 1
#define CONFIG_STACKTRACE 1
#define CONFIG_HAVE_PCI 1
#define CONFIG_EXTCON 1
#define CONFIG_SCSI_SAS_LIBSAS 1
#define CONFIG_NETFILTER_XT_TARGET_IDLETIMER_MODULE 1
#define CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC 1
#define CONFIG_IIO_ST_ACCEL_3AXIS_MODULE 1
#define CONFIG_USB_FUNCTIONFS_ETH 1
#define CONFIG_HAS_IOPORT 1
#define CONFIG_CC_HAS_SIGN_RETURN_ADDRESS 1
#define CONFIG_PHYLIB_LEDS 1
#define CONFIG_CRYPTO_DRBG 1
#define CONFIG_OF_EARLY_FLATTREE 1
#define CONFIG_DRM_I2C_ADV7511_MODULE 1
#define CONFIG_WLAN_VENDOR_ADMTEK 1
#define CONFIG_CGROUP_CPUACCT 1
#define CONFIG_HAVE_FAST_GUP 1
#define CONFIG_ARM64_PA_BITS 48
#define CONFIG_NET_VENDOR_VIA 1
#define CONFIG_SUN50I_DE2_BUS 1
#define CONFIG_HZ 250
#define CONFIG_SERIAL_8250_SHARE_IRQ 1
#define CONFIG_USB_RTL8152_MODULE 1
#define CONFIG_USB_CONFIGFS_F_UAC2 1
#define CONFIG_I2C_HELPER_AUTO 1
#define CONFIG_NETFILTER_XT_MATCH_U32_MODULE 1
#define CONFIG_KVM_XFER_TO_GUEST_WORK 1
#define CONFIG_SQUASHFS_ZLIB 1
#define CONFIG_HISILICON_ERRATUM_161010101 1
#define CONFIG_NLS_ISO8859_4_MODULE 1
#define CONFIG_SERIAL_8250_NR_UARTS 4
#define CONFIG_ARCH_HAS_STRICT_MODULE_RWX 1
#define CONFIG_ARM64_WORKAROUND_CLEAN_CACHE 1
#define CONFIG_CC_IS_GCC 1
#define CONFIG_DMA_OPS 1
#define CONFIG_NET_EGRESS 1
#define CONFIG_XEN_AUTO_XLATE 1
#define CONFIG_NET_VENDOR_ARC 1
#define CONFIG_IP_SET_HASH_MAC_MODULE 1
#define CONFIG_INET_AH_MODULE 1
#define CONFIG_AS_HAS_CFI_NEGATE_RA_STATE 1
#define CONFIG_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_CRYPTO_SM4_ARM64_CE 1
#define CONFIG_DRM_I2C_CH7006_MODULE 1
#define CONFIG_MARVELL_PHY_MODULE 1
#define CONFIG_NFT_SOCKET_MODULE 1
#define CONFIG_HAVE_PERF_USER_STACK_DUMP 1
#define CONFIG_CGROUP_PERF 1
#define CONFIG_NLATTR 1
#define CONFIG_TCP_CONG_CUBIC 1
#define CONFIG_NR_CPUS 64
#define CONFIG_SUSPEND_FREEZER 1
#define CONFIG_ARM64_ERRATUM_1418040 1
#define CONFIG_MMC_SDHCI 1
#define CONFIG_SND_SUPPORT_OLD_API 1
#define CONFIG_NETFILTER_XT_CONNMARK_MODULE 1
#define CONFIG_SOCIONEXT_SYNQUACER_PREITS 1
#define CONFIG_IIO_ST_ACCEL_SPI_3AXIS_MODULE 1
#define CONFIG_MOUSE_PS2_TRACKPOINT 1
#define CONFIG_CRYPTO_CHACHA20 1
#define CONFIG_NFT_COMPAT_MODULE 1
#define CONFIG_SYSFS 1
#define CONFIG_IP_SET_BITMAP_IPMAC_MODULE 1
#define CONFIG_USB_DEFAULT_PERSIST 1
#define CONFIG_AS_HAS_NON_CONST_LEB128 1
#define CONFIG_INPUT_TOUCHSCREEN 1
#define CONFIG_EDAC_LEGACY_SYSFS 1
#define CONFIG_DRM_PANEL_BRIDGE 1
#define CONFIG_ROCKCHIP_PHY 1
#define CONFIG_NF_CONNTRACK_LABELS 1
#define CONFIG_IP_NF_MATCH_AH_MODULE 1
#define CONFIG_ARM64_SVE 1
#define CONFIG_USB_EHCI_HCD_PLATFORM 1
#define CONFIG_PINCTRL_SUN50I_H5 1
#define CONFIG_BLK_DEV_BSG_COMMON 1
#define CONFIG_CAVIUM_ERRATUM_22375 1
#define CONFIG_ASN1 1
#define CONFIG_NETFILTER_XT_MATCH_LIMIT_MODULE 1
#define CONFIG_XZ_DEC_ARM 1
#define CONFIG_NLS_CODEPAGE_775_MODULE 1
#define CONFIG_USB_CONFIGFS_EEM 1
#define CONFIG_PTP_1588_CLOCK_OPTIONAL 1
#define CONFIG_FB_DMAMEM_HELPERS 1
#define CONFIG_CRYPTO_HASH_INFO 1
#define CONFIG_FB_SYS_FOPS 1
#define CONFIG_EXT2_FS_SECURITY 1
#define CONFIG_HAVE_SYSCALL_TRACEPOINTS 1
#define CONFIG_HAVE_ARCH_HUGE_VMALLOC 1
#define CONFIG_ARM_SMMU_DISABLE_BYPASS_BY_DEFAULT 1
#define CONFIG_NETFILTER_XT_MATCH_DEVGROUP_MODULE 1
#define CONFIG_IO_WQ 1
#define CONFIG_GPIO_XGENE 1
#define CONFIG_DECOMPRESS_ZSTD 1
#define CONFIG_IIO_ST_PRESS_SPI_MODULE 1
#define CONFIG_PM_DEVFREQ 1
#define CONFIG_MARVELL_10G_PHY_MODULE 1
#define CONFIG_FB 1
#define CONFIG_IP_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_NLS_CODEPAGE_865_MODULE 1
#define CONFIG_I2C_COMPAT 1
#define CONFIG_KEYBOARD_OPENCORES_MODULE 1
#define CONFIG_DRM_SCHED 1
#define CONFIG_WLAN_VENDOR_ZYDAS 1
#define CONFIG_SPARSEMEM_VMEMMAP_ENABLE 1
#define CONFIG_LEDS_TRIGGER_CPU 1
#define CONFIG_DRM_SUN4I 1
#define CONFIG_ARM_GIC_V3 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_SIG 1
#define CONFIG_VIRTUALIZATION 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_RTC_I2C_AND_SPI 1
#define CONFIG_BT_HCIUART_MODULE 1
#define CONFIG_RT2800USB_RT33XX 1
#define CONFIG_ARM64_TLB_RANGE 1
#define CONFIG_HAVE_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_IRQ_FASTEOI_HIERARCHY_HANDLERS 1
#define CONFIG_ARM_PSCI_FW 1
#define CONFIG_LEGACY_DIRECT_IO 1
#define CONFIG_IP_SET_MODULE 1
#define CONFIG_THERMAL 1
#define CONFIG_SYNC_FILE 1
#define CONFIG_USB_ULPI 1
#define CONFIG_BRCMUTIL_MODULE 1
#define CONFIG_VETH_MODULE 1
#define CONFIG_STACKPROTECTOR 1
#define CONFIG_IRQ_BYPASS_MANAGER 1
#define CONFIG_ARCH_ENABLE_SPLIT_PMD_PTLOCK 1
#define CONFIG_DRM_PANEL_FEIXIN_K101_IM2BA02 1
#define CONFIG_MMC_SDHCI_CADENCE 1
#define CONFIG_CMA_SIZE_MBYTES 256
#define CONFIG_COMMON_CLK_PWM 1
#define CONFIG_CRYPTO_LIB_CHACHA_MODULE 1
#define CONFIG_HAVE_ARCH_KGDB 1
#define CONFIG_ARCH_USE_QUEUED_SPINLOCKS 1
#define CONFIG_NF_TPROXY_IPV4_MODULE 1
#define CONFIG_BLK_DEBUG_FS 1
#define CONFIG_VIDEOBUF2_V4L2 1
#define CONFIG_CPU_FREQ_GOV_SCHEDUTIL 1
#define CONFIG_NET_VENDOR_INTEL 1
#define CONFIG_HAVE_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_ARM64_WORKAROUND_REPEAT_TLBI 1
#define CONFIG_RPS 1
#define CONFIG_USB_NET_ZAURUS_MODULE 1
#define CONFIG_INET6_XFRM_TUNNEL_MODULE 1
#define CONFIG_PROC_PID_CPUSET 1
#define CONFIG_USB_NET_AX88179_178A_MODULE 1
#define CONFIG_NF_TABLES_BRIDGE_MODULE 1
#define CONFIG_PM_GENERIC_DOMAINS 1
#define CONFIG_LEGACY_PTY_COUNT 16
#define CONFIG_PM_WAKELOCKS_LIMIT 100
#define CONFIG_GENERIC_CSUM 1
#define CONFIG_MTD_MAP_BANK_WIDTH_2 1
#define CONFIG_NFT_REJECT_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORTIP_MODULE 1
#define CONFIG_GENERIC_IDLE_POLL_SETUP 1
#define CONFIG_RESET_SIMPLE 1
#define CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS 1
#define CONFIG_MDIO_BUS_MUX 1
#define CONFIG_WLAN_VENDOR_MEDIATEK 1
#define CONFIG_CUSE_MODULE 1
#define CONFIG_NF_TABLES_IPV4 1
#define CONFIG_IP_MULTICAST 1
#define CONFIG_SQUASHFS_XZ 1
#define CONFIG_HID_LOGITECH_DJ 1
#define CONFIG_ARCH_HAS_PTE_DEVMAP 1
#define CONFIG_BT_LEDS 1
#define CONFIG_CRYPTO_DH 1
#define CONFIG_TICK_ONESHOT 1
#define CONFIG_CRYPTO_CTR 1
#define CONFIG_AS_HAS_ARMV8_2 1
#define CONFIG_XARRAY_MULTI 1
#define CONFIG_LOCK_MM_AND_FIND_VMA 1
#define CONFIG_WIRELESS_EXT 1
#define CONFIG_VIDEO_GC2145_MODULE 1
#define CONFIG_HW_RANDOM_MODULE 1
#define CONFIG_MUTEX_SPIN_ON_OWNER 1
#define CONFIG_BT_HCIBTUSB_RTL 1
#define CONFIG_VIRTIO_VSOCKETS_COMMON_MODULE 1
#define CONFIG_CGROUP_NET_CLASSID 1
#define CONFIG_NETFILTER_SYNPROXY_MODULE 1
#define CONFIG_NLS_CODEPAGE_737_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_TRACER 1
#define CONFIG_I2C_DESIGNWARE_PLATFORM 1
#define CONFIG_BUFFER_HEAD 1
#define CONFIG_ARM64_AMU_EXTN 1
#define CONFIG_OF_MDIO 1
#define CONFIG_HAVE_CMPXCHG_LOCAL 1
#define CONFIG_VIDEOBUF2_CORE 1
#define CONFIG_CRYPTO_BLAKE2B_MODULE 1
#define CONFIG_RTL8723CS_MODULE 1
#define CONFIG_TREE_SRCU 1
#define CONFIG_CRYPTO_NULL2 1
#define CONFIG_NTFS_FS_MODULE 1
#define CONFIG_RT2X00_LIB_CRYPTO 1
#define CONFIG_CRYPTO_LIB_DES_MODULE 1
#define CONFIG_HNS_ENET 1
#define CONFIG_SERIAL_8250_DMA 1
#define CONFIG_FUNCTION_ALIGNMENT_4B 1
#define CONFIG_BASE_SMALL 0
#define CONFIG_INPUT_GPIO_VIBRA 1
#define CONFIG_PM_WAKELOCKS 1
#define CONFIG_SCSI_SAS_ATTRS 1
#define CONFIG_VIDEO_CMDLINE 1
#define CONFIG_COMPACTION 1
#define CONFIG_NFS_V2 1
#define CONFIG_NF_DUP_IPV6_MODULE 1
#define CONFIG_Z3FOLD 1
#define CONFIG_BLK_CGROUP_PUNT_BIO 1
#define CONFIG_SUN6I_R_INTC 1
#define CONFIG_PROC_FS 1
#define CONFIG_MTD_BLOCK 1
#define CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE 1
#define CONFIG_VIDEOBUF2_VMALLOC_MODULE 1
#define CONFIG_NFT_BRIDGE_REJECT_MODULE 1
#define CONFIG_GENERIC_BUG_RELATIVE_POINTERS 1
#define CONFIG_WEXT_PRIV 1
#define CONFIG_MMU_GATHER_RCU_TABLE_FREE 1
#define CONFIG_NET_VENDOR_ROCKER 1
#define CONFIG_XFRM_AH_MODULE 1
#define CONFIG_SCSI_LOWLEVEL 1
#define CONFIG_IP_VS_PROTO_AH_ESP 1
#define CONFIG_MEMFD_CREATE 1
#define CONFIG_IRQ_FORCED_THREADING 1
#define CONFIG_ARM64_CONT_PTE_SHIFT 4
#define CONFIG_USB_F_HID_MODULE 1
#define CONFIG_NLS_ISO8859_3_MODULE 1
#define CONFIG_EXT2_FS_XATTR 1
#define CONFIG_CRYPTO_CMAC_MODULE 1
#define CONFIG_DRM_FBDEV_EMULATION 1
#define CONFIG_SND_MODULE 1
#define CONFIG_ARCH_HAVE_ELF_PROT 1
#define CONFIG_SUN8I_H3_CCU 1
#define CONFIG_IP_VS_SH_MODULE 1
#define CONFIG_ARCH_USE_GNU_PROPERTY 1
#define CONFIG_USB_F_OBEX_MODULE 1
#define CONFIG_USB_PEGASUS_MODULE 1
#define CONFIG_PHY_SUN6I_MIPI_DPHY 1
#define CONFIG_IIO_ST_MAGN_3AXIS_MODULE 1
#define CONFIG_SPI_PL022 1
#define CONFIG_SUN6I_MSGBOX 1
#define CONFIG_LD_ORPHAN_WARN 1
#define CONFIG_PINCTRL_SUN50I_H616_R 1
#define CONFIG_V4L_PLATFORM_DRIVERS 1
#define CONFIG_RFKILL_INPUT 1
#define CONFIG_NET_VENDOR_NATSEMI 1
#define CONFIG_USB_MUSB_DUAL_ROLE 1
#define CONFIG_BLK_DEV_BSGLIB 1
#define CONFIG_USB_F_MASS_STORAGE_MODULE 1
#define CONFIG_IKCONFIG 1
#define CONFIG_NFT_XFRM_MODULE 1
#define CONFIG_NET_VENDOR_GOOGLE 1
#define CONFIG_GENERIC_IRQ_MIGRATION 1
#define CONFIG_NET_VENDOR_NETRONOME 1
#define CONFIG_NFS_USE_KERNEL_DNS 1
#define CONFIG_DMA_ENGINE_RAID 1
#define CONFIG_ARCH_HAS_FORTIFY_SOURCE 1
#define CONFIG_GCC_VERSION 120100
#define CONFIG_CRYPTO_LIB_POLY1305_RSIZE 9
#define CONFIG_TRANS_TABLE 1
#define CONFIG_SYSCTL 1
#define CONFIG_CC_CAN_LINK_STATIC 1
#define CONFIG_ARCH_HAS_GCOV_PROFILE_ALL 1
#define CONFIG_SND_USB_AUDIO_USE_MEDIA_CONTROLLER 1
#define CONFIG_BRIDGE_IGMP_SNOOPING 1
#define CONFIG_PHYS_ADDR_T_64BIT 1
#define CONFIG_THREAD_INFO_IN_TASK 1
#define CONFIG_POWER_RESET_VEXPRESS 1
#define CONFIG_AHCI_CEVA_MODULE 1
#define CONFIG_NET_VENDOR_LITEX 1
#define CONFIG_HAVE_C_RECORDMCOUNT 1
#define CONFIG_GENERIC_MSI_IRQ 1
#define CONFIG_USB_NET_DM9601_MODULE 1
#define CONFIG_HAVE_ARCH_TRACEHOOK 1
#define CONFIG_IIO_ST_ACCEL_I2C_3AXIS_MODULE 1
#define CONFIG_NO_IOPORT_MAP 1
#define CONFIG_CIFS_MODULE 1
#define CONFIG_DRM_FBDEV_OVERALLOC 100
#define CONFIG_XFRM_USER 1
#define CONFIG_CPUFREQ_DT_PLATDEV 1
#define CONFIG_TASK_DELAY_ACCT 1
#define CONFIG_ARCH_HAS_NON_OVERLAPPING_ADDRESS_SPACE 1
#define CONFIG_EXTCON_USB_GPIO 1
#define CONFIG_NET_NS 1
#define CONFIG_USB_ISP1760_DUAL_ROLE 1
#define CONFIG_MEMORY 1
#define CONFIG_HAVE_PERF_EVENTS 1
#define CONFIG_SENSORS_LIS3_I2C_MODULE 1
#define CONFIG_ATA_SFF 1
#define CONFIG_EXT3_FS_SECURITY 1
#define CONFIG_VFIO_CONTAINER 1
#define CONFIG_PPP_ASYNC_MODULE 1
#define CONFIG_HAVE_ALIGNED_STRUCT_PAGE 1
#define CONFIG_NET_VENDOR_SOLARFLARE 1
#define CONFIG_NLS_CODEPAGE_866_MODULE 1
#define CONFIG_KEYBOARD_LM8323_MODULE 1
#define CONFIG_STMMAC_ETH_MODULE 1
#define CONFIG_HAVE_KVM_VCPU_RUN_PID_CHANGE 1
#define CONFIG_QCOM_HIDMA_MGMT 1
#define CONFIG_DEBUG_MEMORY_INIT 1
#define CONFIG_XFRM_ESP_MODULE 1
#define CONFIG_ARCH_HAS_RESET_CONTROLLER 1
#define CONFIG_KERNEL_MODE_NEON 1
#define CONFIG_ARM_SCPI_POWER_DOMAIN 1
#define CONFIG_ARM_SCPI_CPUFREQ 1
#define CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE 1
#define CONFIG_CRYPTO_USER_API_SKCIPHER 1
#define CONFIG_BPF_JIT_ALWAYS_ON 1
#define CONFIG_NET_9P_FD 1
#define CONFIG_CMA_AREAS 7
#define CONFIG_LTO_NONE 1
#define CONFIG_DEBUG_FS_ALLOW_ALL 1
#define CONFIG_ARM_GIC_MAX_NR 1
#define CONFIG_FB_DEFERRED_IO 1
#define CONFIG_SECURITY 1
#define CONFIG_MAX_SKB_FRAGS 17
#define CONFIG_SND_TIMER_MODULE 1
#define CONFIG_KVM_MMIO 1
#define CONFIG_USB_EHCI_TT_NEWSCHED 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_BLK_DEV 1
#define CONFIG_MAC80211_RC_DEFAULT "minstrel_ht"
#define CONFIG_RT2800USB_RT55XX 1
#define CONFIG_CHROME_PLATFORMS 1
#define CONFIG_BRIDGE_NETFILTER_MODULE 1
#define CONFIG_CC_HAS_ASM_GOTO_TIED_OUTPUT 1
#define CONFIG_OF_FLATTREE 1
#define CONFIG_HAVE_ARCH_KFENCE 1
#define CONFIG_WLAN_VENDOR_SILABS 1
#define CONFIG_IOMMU_API 1
#define CONFIG_GPIO_GENERIC 1
#define CONFIG_TRACING_SUPPORT 1
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_VFIO 1
#define CONFIG_NETFILTER_XT_TARGET_CONNMARK_MODULE 1
#define CONFIG_NET_RX_BUSY_POLL 1
#define CONFIG_NET_VENDOR_SOCIONEXT 1
#define CONFIG_CRYPTO_ANSI_CPRNG 1
#define CONFIG_ZONE_DMA32 1
#define CONFIG_STAGING_MEDIA 1
#define CONFIG_ARCH_SUPPORTS_KEXEC 1
#define CONFIG_DRM_PANEL 1
#define CONFIG_PRINTK_TIME 1
#define CONFIG_EXT2_FS_POSIX_ACL 1
#define CONFIG_TRACE_IRQFLAGS_NMI_SUPPORT 1
#define CONFIG_TASKS_RCU_GENERIC 1
#define CONFIG_SECCOMP_FILTER 1
#define CONFIG_IRQCHIP 1
#define CONFIG_PPP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_QUOTA_MODULE 1
#define CONFIG_TOUCHSCREEN_ATMEL_MXT_MODULE 1
#define CONFIG_NFT_FIB_IPV4_MODULE 1
#define CONFIG_INET_DIAG 1
#define CONFIG_CRYPTO_GHASH 1
#define CONFIG_PSTORE 1
#define CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW 1
#define CONFIG_HAVE_SCHED_AVG_IRQ 1
#define CONFIG_NF_NAT_FTP_MODULE 1
#define CONFIG_MAC80211_RC_MINSTREL 1
#define CONFIG_IIO_CONSUMERS_PER_TRIGGER 2
#define CONFIG_NF_CT_PROTO_UDPLITE 1
#define CONFIG_IKCONFIG_PROC 1
#define CONFIG_IP6_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_ELF_CORE 1
#define CONFIG_DEV_COREDUMP 1
#define CONFIG_TEXTSEARCH 1
#define CONFIG_USB_DWC3 1
#define CONFIG_NF_CT_NETLINK_HELPER_MODULE 1
#define CONFIG_HAVE_CONTEXT_TRACKING_USER 1
#define CONFIG_USB_SUPPORT 1
#define CONFIG_WLAN_VENDOR_ST 1
#define CONFIG_PCP_BATCH_SCALE_MAX 5
#define CONFIG_BRCMFMAC_PROTO_BCDC 1
#define CONFIG_SOC_BUS 1
#define CONFIG_STAGING 1
#define CONFIG_F2FS_FS_MODULE 1
#define CONFIG_TOUCHSCREEN_EDT_FT5X06 1
#define CONFIG_SENSORS_LIS3LV02D_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO_BARE 1
#define CONFIG_DMA_CMA 1
#define CONFIG_PAGE_POOL 1
#define CONFIG_CRYPTO_SM4 1
#define CONFIG_ARM64_ERRATUM_2966298 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_LEDS_GPIO 1
#define CONFIG_SCHED_INFO 1
#define CONFIG_IP_VS_FTP_MODULE 1
#define CONFIG_AS_VERSION 23800
#define CONFIG_CC_HAS_INT128 1
#define CONFIG_FANOTIFY_ACCESS_PERMISSIONS 1
#define CONFIG_MMC_DW_K3 1
#define CONFIG_IIO_ST_PRESS_I2C_MODULE 1
#define CONFIG_CFG80211_WEXT 1
#define CONFIG_WLAN_VENDOR_MARVELL 1
#define CONFIG_NETFILTER_XT_MATCH_PHYSDEV_MODULE 1
#define CONFIG_NOP_USB_XCEIV_MODULE 1
#define CONFIG_NET_SOCK_MSG 1
#define CONFIG_AUDIT_ARCH_COMPAT_GENERIC 1
#define CONFIG_CC_OPTIMIZE_FOR_PERFORMANCE 1
#define CONFIG_SERIAL_8250_DWLIB 1
#define CONFIG_ARM64_CONT_PMD_SHIFT 4
#define CONFIG_BLK_DEV_RAM_MODULE 1
#define CONFIG_USB_F_NCM_MODULE 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS 11
#define CONFIG_NETFILTER_XT_MATCH_STATE_MODULE 1
#define CONFIG_IIO_TRIGGERED_BUFFER_MODULE 1
#define CONFIG_BRIDGE_EBT_LOG_MODULE 1
#define CONFIG_MICROCHIP_PHY_MODULE 1
#define CONFIG_DRM 1
#define CONFIG_ASYNC_TX_DISABLE_PQ_VAL_DMA 1
#define CONFIG_POSIX_MQUEUE_SYSCTL 1
#define CONFIG_MFD_AC100_MODULE 1
#define CONFIG_ARM64 1
#define CONFIG_VHOST_MENU 1
#define CONFIG_PREEMPT 1
#define CONFIG_FB_CFB_COPYAREA 1
#define CONFIG_USB_F_ECM_MODULE 1
#define CONFIG_LEDS_SYSCON 1
#define CONFIG_BRIDGE_EBT_STP_MODULE 1
#define CONFIG_HAVE_KVM_IRQCHIP 1
#define CONFIG_USB_ULPI_BUS 1
#define CONFIG_CROS_USBPD_NOTIFY 1
#define CONFIG_BRIDGE_EBT_ARP_MODULE 1
#define CONFIG_NET_VENDOR_MICROSEMI 1
#define CONFIG_BMC150_ACCEL_I2C_MODULE 1
#define CONFIG_ARCH_HAS_TICK_BROADCAST 1
#define CONFIG_SND_SOC_MSM8916_WCD_ANALOG_MODULE 1
#define CONFIG_IP6_NF_MATCH_EUI64_MODULE 1
#define CONFIG_MWIFIEX_MODULE 1
#define CONFIG_BINARY_PRINTF 1
#define CONFIG_VFIO_GROUP 1
#define CONFIG_ZSTD_DECOMPRESS 1
#define CONFIG_SND_SOC_SIMPLE_AMPLIFIER_MODULE 1
#define CONFIG_ARM64_ERRATUM_1165522 1
#define CONFIG_BT_HCIUART_RTL 1
#define CONFIG_SYSFS_SYSCALL 1
#define CONFIG_AF8133J_MODULE 1
#define CONFIG_WLAN_VENDOR_QUANTENNA 1
#define CONFIG_SND_PCM_TIMER 1
#define CONFIG_ARCH_HAS_SET_DIRECT_MAP 1
#define CONFIG_SYSVIPC_SYSCTL 1
#define CONFIG_WLAN_VENDOR_TI 1
#define CONFIG_IP_VS_IPV6 1
#define CONFIG_DMA_SHARED_BUFFER 1
#define CONFIG_RTC_SYSTOHC 1
#define CONFIG_OF_ADDRESS 1
#define CONFIG_DECOMPRESS_GZIP 1
#define CONFIG_NLS_MAC_CELTIC_MODULE 1
#define CONFIG_THERMAL_GOV_POWER_ALLOCATOR 1
#define CONFIG_AX88796B_PHY_MODULE 1
#define CONFIG_DECOMPRESS_LZO 1
#define CONFIG_CRYPTO_XXHASH_MODULE 1
#define CONFIG_64BIT 1
#define CONFIG_QUOTA 1
#define CONFIG_ZBUD 1
#define CONFIG_PARTITION_PERCPU 1
#define CONFIG_MMC_SDHCI_PLTFM 1
#define CONFIG_I2C_CHARDEV 1
#define CONFIG_RPMSG_QCOM_GLINK 1
#define CONFIG_LLC_MODULE 1
#define CONFIG_ARCH_USE_QUEUED_RWLOCKS 1
#define CONFIG_ARCH_KEEP_MEMBLOCK 1
#define CONFIG_REGMAP_MMIO 1
#define CONFIG_GPIO_MB86S7X 1
#define CONFIG_ENERGY_MODEL 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST 1
#define CONFIG_POWER_SUPPLY_HWMON 1
#define CONFIG_MOUSE_PS2_SYNAPTICS 1
#define CONFIG_ATA_BMDMA 1
#define CONFIG_XZ_DEC_ARMTHUMB 1
#define CONFIG_USB_F_UAC1_MODULE 1
#define CONFIG_MEMORY_FAILURE 1
#define CONFIG_NFS_V4_1 1
#define CONFIG_ARCH_USE_CMPXCHG_LOCKREF 1
#define CONFIG_ARCH_WANT_FRAME_POINTERS 1
#define CONFIG_REGMAP 1
#define CONFIG_NLS_UTF8_MODULE 1
#define CONFIG_FB_IOMEM_HELPERS 1
#define CONFIG_USB_DWC2_DUAL_ROLE 1
#define CONFIG_HAVE_MOD_ARCH_SPECIFIC 1
#define CONFIG_FB_NOTIFY 1
#define CONFIG_STRICT_MODULE_RWX 1
#define CONFIG_VHOST_IOTLB_MODULE 1
#define CONFIG_SUN50I_ERRATUM_UNKNOWN1 1
#define CONFIG_USB_USBNET_MODULE 1
#define CONFIG_ARM64_ERRATUM_834220 1
#define CONFIG_SYSCTL_EXCEPTION_TRACE 1
#define CONFIG_SYSVIPC_COMPAT 1
#define CONFIG_GPIO_PCA953X 1
#define CONFIG_INPUT_XEN_KBDDEV_FRONTEND 1
#define CONFIG_FHANDLE 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT_MULTI 1
#define CONFIG_WATCHDOG_OPEN_TIMEOUT 0
#define CONFIG_BPFILTER_UMH_MODULE 1
#define CONFIG_TOUCHSCREEN_GOODIX 1
#define CONFIG_NEW_LEDS 1
#define CONFIG_CRYPTO_LIB_SHA256 1
#define CONFIG_SWAP 1
#define CONFIG_CRC64 1
#define CONFIG_FW_CACHE 1
#define CONFIG_NFT_BRIDGE_META_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET_ENABLE_MODULE 1
#define CONFIG_MAC80211_MODULE 1
#define CONFIG_STACKPROTECTOR_PER_TASK 1
#define CONFIG_CRC_CCITT 1
#define CONFIG_NET_VENDOR_CAVIUM 1
#define CONFIG_GPIOLIB_IRQCHIP 1
#define CONFIG_EXT3_FS_POSIX_ACL 1
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_CMDLINE_FROM_BOOTLOADER 1
#define CONFIG_HISILICON_ERRATUM_161600802 1
#define CONFIG_NETFILTER_NETLINK_MODULE 1
#define CONFIG_MODULE_UNLOAD 1
#define CONFIG_PREEMPT_COUNT 1
#define CONFIG_NET_VENDOR_ENGLEDER 1
#define CONFIG_BT_LE 1
#define CONFIG_TYPEC_ANX7688_MODULE 1
#define CONFIG_SND_SOC_AK4613_MODULE 1
#define CONFIG_CMA 1
#define CONFIG_RWSEM_SPIN_ON_OWNER 1
#define CONFIG_GENERIC_PINMUX_FUNCTIONS 1
#define CONFIG_CC_HAS_ASM_GOTO_OUTPUT 1
#define CONFIG_BITREVERSE 1
#define CONFIG_DEVPORT 1
#define CONFIG_PREEMPTION 1
#define CONFIG_MACB_USE_HWSTAMP 1
#define CONFIG_X509_CERTIFICATE_PARSER 1
#define CONFIG_BLK_DEV_RAM_SIZE 4096
#define CONFIG_USB_SERIAL_WWAN_MODULE 1
#define CONFIG_ARCH_HAVE_TRACE_MMIO_ACCESS 1
#define CONFIG_NFT_TPROXY_MODULE 1
#define CONFIG_PTP_1588_CLOCK_KVM 1
#define CONFIG_FB_MODE_HELPERS 1
#define CONFIG_NLS_ISO8859_13_MODULE 1
#define CONFIG_NLS_ISO8859_8_MODULE 1
#define CONFIG_NF_CONNTRACK_MODULE 1
#define CONFIG_LCD_CLASS_DEVICE 1
#define CONFIG_MDIO_DEVRES 1
#define CONFIG_LSM "yama,loadpin,integrity,selinux,smack,tomoyo,apparmor"
#define CONFIG_ARCH_DMA_ADDR_T_64BIT 1
#define CONFIG_FILE_LOCKING 1
#define CONFIG_CRC64_ROCKSOFT 1
#define CONFIG_SND_SOC_I2C_AND_SPI_MODULE 1
#define CONFIG_ZSWAP 1
#define CONFIG_AIO 1
#define CONFIG_OF 1
#define CONFIG_PERF_EVENTS 1
#define CONFIG_GENERIC_TIME_VSYSCALL 1
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#define CONFIG_HAVE_MOVE_PMD 1
#define CONFIG_IOMMU_IO_PGTABLE 1
#define CONFIG_LEDS_CLASS 1
#define CONFIG_IP6_NF_MATCH_HL_MODULE 1
#define CONFIG_KALLSYMS_BASE_RELATIVE 1
#define CONFIG_IP_VS_TAB_BITS 12
#define CONFIG_IP6_NF_MATCH_OPTS_MODULE 1
#define CONFIG_SCSI_SAS_HOST_SMP 1
#define CONFIG_SUN8I_R_CCU 1
#define CONFIG_CAVIUM_ERRATUM_23144 1
#define CONFIG_AS_HAS_LSE_ATOMICS 1
#define CONFIG_RTC_INTF_DEV 1
#define CONFIG_MTD_MAP_BANK_WIDTH_4 1
#define CONFIG_AS_HAS_SHA3 1
#define CONFIG_FUJITSU_ERRATUM_010001 1
#define CONFIG_IIO_ST_SENSORS_SPI_MODULE 1
#define CONFIG_CRYPTO_AES_ARM64_BS 1
#define CONFIG_HID_SUPPORT 1
#define CONFIG_DCACHE_WORD_ACCESS 1
#define CONFIG_IP6_NF_TARGET_NPT_MODULE 1
#define CONFIG_CPU_LITTLE_ENDIAN 1
#define CONFIG_PSTORE_COMPRESS 1
#define CONFIG_CRYPTO_POLY1305_NEON_MODULE 1
#define CONFIG_MAGIC_SYSRQ_SERIAL_SEQUENCE ""
#define CONFIG_NETFILTER_XT_MATCH_OSF_MODULE 1
#define CONFIG_MESSAGE_LOGLEVEL_DEFAULT 4
#define CONFIG_IP_VS_PROTO_UDP 1
#define CONFIG_CMA_ALIGNMENT 8
#define CONFIG_VIDEO_CAMERA_SENSOR 1
#define CONFIG_NLS_DEFAULT "utf8"
#define CONFIG_UTS_NS 1
#define CONFIG_NF_CT_PROTO_GRE 1
#define CONFIG_VIDEO_NOMODESET 1
#define CONFIG_NF_CT_NETLINK_MODULE 1
#define CONFIG_USB_NET_SR9800_MODULE 1
#define CONFIG_DMA_ENGINE 1
#define CONFIG_CGROUP_PIDS 1
#define CONFIG_CRYPTO_AEAD2 1
#define CONFIG_MOUSE_PS2 1
#define CONFIG_IP_VS_SH_TAB_BITS 8
#define CONFIG_NETFILTER_XT_MATCH_HL_MODULE 1
#define CONFIG_QCOM_QDF2400_ERRATUM_0065 1
#define CONFIG_ARM64_E0PD 1
#define CONFIG_CRYPTO_ALGAPI2 1
#define CONFIG_NETFILTER_XT_TARGET_LED_MODULE 1
#define CONFIG_CPU_FREQ_DEFAULT_GOV_CONSERVATIVE 1
#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS 1
#define CONFIG_INPUT 1
#define CONFIG_PROC_SYSCTL 1
#define CONFIG_FWNODE_MDIO 1
#define CONFIG_NETFILTER_XT_TARGET_CT_MODULE 1
#define CONFIG_RD_LZ4 1
#define CONFIG_MMU 1
#define CONFIG_LD_VERSION 23800
#define CONFIG_BRIDGE_EBT_NFLOG_MODULE 1
#define CONFIG_HAVE_HARDLOCKUP_DETECTOR_BUDDY 1
#define CONFIG_KUSER_HELPERS 1
#define CONFIG_ZPOOL 1
